@@ -5,8 +5,6 @@
 
 # pylint: disable=too-many-lines
 
-from __future__ import print_function
-
 import argparse
 import datetime
 import json
@@ -17,7 +15,6 @@ import sys
 import time
 import copy
 from importlib import import_module
-import six
 
 # pylint: disable=unused-import
 from azure.cli.core.commands.constants import (
@@ -26,10 +23,11 @@ from azure.cli.core.commands.constants import (
 from azure.cli.core.commands.parameters import (
     AzArgumentContext, patch_arg_make_required, patch_arg_make_optional)
 from azure.cli.core.extension import get_extension
-from azure.cli.core.util import get_command_type_kwarg, read_file_content, get_arg_list, poller_classes
+from azure.cli.core.util import (
+    get_command_type_kwarg, read_file_content, get_arg_list, poller_classes)
 from azure.cli.core.local_context import LocalContextAction
-import azure.cli.core.telemetry as telemetry
-
+from azure.cli.core import telemetry
+from azure.cli.core.commands.progress import IndeterminateProgressBar
 
 from knack.arguments import CLICommandArgument
 from knack.commands import CLICommand, CommandGroup, PREVIEW_EXPERIMENTAL_CONFLICT_ERROR
@@ -37,7 +35,7 @@ from knack.deprecation import ImplicitDeprecated, resolve_deprecate_info
 from knack.invocation import CommandInvoker
 from knack.preview import ImplicitPreviewItem, PreviewItem, resolve_preview_info
 from knack.experimental import ImplicitExperimentalItem, ExperimentalItem, resolve_experimental_info
-from knack.log import get_logger
+from knack.log import get_logger, CLILogging
 from knack.util import CLIError, CommandResultItem, todict
 from knack.events import EVENT_INVOKER_TRANSFORM_RESULT
 from knack.validators import DefaultStr
@@ -109,7 +107,7 @@ def _expand_file_prefixed_files(args):
         except IndexError:
             return _maybe_load_file(arg_split[0])
 
-    return list([_expand_file_prefix(arg) for arg in args])
+    return [_expand_file_prefix(arg) for arg in args]
 
 
 def _pre_command_table_create(cli_ctx, args):
@@ -306,7 +304,7 @@ class AzCliCommand(CLICommand):
                 local_context = self.cli_ctx.local_context
                 value = local_context.get(self.name, lca.name)
                 if value:
-                    logger.debug("local context '%s' for arg %s", value, arg.name)
+                    logger.debug("parameter persistence '%s' for arg %s", value, arg.name)
                     overrides.settings['default'] = DefaultStr(value)
                     overrides.settings['required'] = False
                     overrides.settings['default_value_source'] = 'Local Context'
@@ -564,7 +562,8 @@ class AzCliCommandInvoker(CommandInvoker):
         self.cli_ctx.raise_event(EVENT_INVOKER_CMD_TBL_LOADED, cmd_tbl=self.commands_loader.command_table,
                                  parser=self.parser)
 
-        arg_check = [a for a in args if a not in ['--debug', '--verbose']]
+        arg_check = [a for a in args if a not in
+                     (CLILogging.DEBUG_FLAG, CLILogging.VERBOSE_FLAG, CLILogging.ONLY_SHOW_ERRORS_FLAG)]
         if not arg_check:
             self.parser.enable_autocomplete()
             subparser = self.parser.subparsers[tuple()]
@@ -598,13 +597,13 @@ class AzCliCommandInvoker(CommandInvoker):
                     value = getattr(parsed_args, name)
                     local_context_args.append((options[0], value))
             if local_context_args:
-                logger.warning('Local context is turned on. Its information is saved in working directory %s. You can '
-                               'run `az local-context off` to turn it off.',
+                logger.warning('Parameter persistence is turned on. Its information is saved in working directory %s. '
+                               'You can run `az config param-persist off` to turn it off.',
                                self.cli_ctx.local_context.effective_working_directory())
                 args_str = []
                 for name, value in local_context_args:
                     args_str.append('{}: {}'.format(name, value))
-                logger.warning('Command argument values from local context: %s', ', '.join(args_str))
+                logger.warning('Command argument values from persistent parameters: %s', ', '.join(args_str))
 
         # TODO: This fundamentally alters the way Knack.invocation works here. Cannot be customized
         # with an event. Would need to be customized via inheritance.
@@ -712,7 +711,7 @@ class AzCliCommandInvoker(CommandInvoker):
         except Exception as ex:  # pylint: disable=broad-except
             if cmd_copy.exception_handler:
                 return cmd_copy.exception_handler(ex)
-            six.reraise(*sys.exc_info())
+            raise
 
     def _run_jobs_serially(self, jobs, ids):
         results, exceptions = [], []
@@ -868,7 +867,8 @@ class AzCliCommandInvoker(CommandInvoker):
 
 
 class LongRunningOperation:  # pylint: disable=too-few-public-methods
-    def __init__(self, cli_ctx, start_msg='', finish_msg='', poller_done_interval_ms=1000.0):
+    def __init__(self, cli_ctx, start_msg='', finish_msg='', poller_done_interval_ms=500.0,
+                 progress_bar=None):
 
         self.cli_ctx = cli_ctx
         self.start_msg = start_msg
@@ -877,6 +877,11 @@ class LongRunningOperation:  # pylint: disable=too-few-public-methods
         self.deploy_dict = {}
         self.last_progress_report = datetime.datetime.now()
 
+        self.progress_bar = None
+        disable_progress_bar = self.cli_ctx.config.getboolean('core', 'disable_progress_bar', False)
+        if not disable_progress_bar and not cli_ctx.only_show_errors:
+            self.progress_bar = progress_bar if progress_bar is not None else IndeterminateProgressBar(cli_ctx)
+
     def _delay(self):
         time.sleep(self.poller_done_interval_ms / 1000.0)
 
@@ -943,20 +948,23 @@ class LongRunningOperation:  # pylint: disable=too-few-public-methods
                             if update:
                                 logger.info(result)
 
-    def __call__(self, poller):
+    def __call__(self, poller):  # pylint: disable=too-many-statements
         from msrest.exceptions import ClientException
+        from azure.core.exceptions import HttpResponseError
 
         correlation_message = ''
-        self.cli_ctx.get_progress_controller().begin()
+        if self.progress_bar:
+            self.progress_bar.begin()
         correlation_id = None
 
         cli_logger = get_logger()  # get CLI logger which has the level set through command lines
         is_verbose = any(handler.level <= logs.INFO for handler in cli_logger.handlers)
+
         telemetry.poll_start()
         poll_flag = False
         while not poller.done():
             poll_flag = True
-            self.cli_ctx.get_progress_controller().add(message='Running')
+
             try:
                 # pylint: disable=protected-access
                 correlation_id = json.loads(
@@ -974,22 +982,36 @@ class LongRunningOperation:  # pylint: disable=too-few-public-methods
                 except Exception as ex:  # pylint: disable=broad-except
                     logger.warning('%s during progress reporting: %s', getattr(type(ex), '__name__', type(ex)), ex)
             try:
+                if self.progress_bar:
+                    self.progress_bar.update_progress()
                 self._delay()
             except KeyboardInterrupt:
-                self.cli_ctx.get_progress_controller().stop()
+                if self.progress_bar:
+                    self.progress_bar.stop()
                 logger.error('Long-running operation wait cancelled.  %s', correlation_message)
                 raise
 
         try:
             result = poller.result()
-        except ClientException as client_exception:
+        except (ClientException, HttpResponseError) as exception:
             from azure.cli.core.commands.arm import handle_long_running_operation_exception
-            self.cli_ctx.get_progress_controller().stop()
-            handle_long_running_operation_exception(client_exception)
+            if self.progress_bar:
+                self.progress_bar.stop()
+            if getattr(exception, 'status_code', None) == 404 and \
+               ('delete' in self.cli_ctx.data['command'] or 'purge' in self.cli_ctx.data['command']):
+                logger.debug('Service returned 404 on the long-running delete or purge operation. CLI treats it as '
+                             'delete or purge successfully but service should fix this behavior.')
+                return None
+            if isinstance(exception, ClientException):
+                handle_long_running_operation_exception(exception)
+            else:
+                raise exception
+        finally:
+            if self.progress_bar:
+                self.progress_bar.end()
+            if poll_flag:
+                telemetry.poll_end()
 
-        self.cli_ctx.get_progress_controller().end()
-        if poll_flag:
-            telemetry.poll_end()
         return result
 
 
@@ -1112,8 +1134,8 @@ def _load_azure_exception_class():
 # pylint: disable=no-member
 def _is_paged(obj):
     # Since loading msrest is expensive, we avoid it until we have to
-    import collections
-    if isinstance(obj, collections.Iterable) \
+    from collections.abc import Iterable
+    if isinstance(obj, Iterable) \
             and not isinstance(obj, list) \
             and not isinstance(obj, dict):
         from msrest.paging import Paged
@@ -1159,6 +1181,12 @@ class CliCommandType:
 class AzCommandGroup(CommandGroup):
 
     def __init__(self, command_loader, group_name, **kwargs):
+        """
+        :param command_loader: The command loader that commands will be registered into
+        :type command_loader: azure.cli.core.AzCommandsLoader
+        :param group_name: The name of the group of commands in the command hierarchy
+        :type group_name: str
+        """
         merged_kwargs = self._merge_kwargs(kwargs, base_kwargs=command_loader.module_kwargs)
         operations_tmpl = merged_kwargs.pop('operations_tmpl', None)
         super(AzCommandGroup, self).__init__(command_loader, group_name,
@@ -1246,16 +1274,24 @@ class AzCommandGroup(CommandGroup):
         return self._command(name, method_name=method_name, custom_command=True, **kwargs)
 
     def _command(self, name, method_name, custom_command=False, **kwargs):
+        from .command_operation import CommandOperation
+
         self._check_stale()
         merged_kwargs = self._flatten_kwargs(kwargs, get_command_type_kwarg(custom_command))
         self._apply_tags(merged_kwargs, kwargs, name)
 
         operations_tmpl = merged_kwargs['operations_tmpl']
-        command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
-        self.command_loader._cli_command(command_name,  # pylint: disable=protected-access
-                                         operation=operations_tmpl.format(method_name),
-                                         **merged_kwargs)
+        op_path = operations_tmpl.format(method_name)
 
+        command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
+        command_operation = CommandOperation(
+            command_loader=self.command_loader,
+            op_path=op_path,
+            **merged_kwargs
+        )
+        self.command_loader.add_cli_command(command_name,
+                                            command_operation=command_operation,
+                                            **merged_kwargs)
         return command_name
 
     # pylint: disable=no-self-use
@@ -1285,27 +1321,31 @@ class AzCommandGroup(CommandGroup):
                                setter_name='create_or_update', setter_type=None, setter_arg_name='parameters',
                                child_collection_prop_name=None, child_collection_key='name', child_arg_name='item_name',
                                custom_func_name=None, custom_func_type=None, **kwargs):
-        from azure.cli.core.commands.arm import _cli_generic_update_command
+        from azure.cli.core.commands.command_operation import GenericUpdateCommandOperation
         self._check_stale()
         merged_kwargs = self._flatten_kwargs(kwargs, get_command_type_kwarg())
         merged_kwargs_custom = self._flatten_kwargs(kwargs, get_command_type_kwarg(custom_command=True))
         self._apply_tags(merged_kwargs, kwargs, name)
 
-        getter_op = self._resolve_operation(merged_kwargs, getter_name, getter_type)
-        setter_op = self._resolve_operation(merged_kwargs, setter_name, setter_type)
-        custom_func_op = self._resolve_operation(merged_kwargs_custom, custom_func_name, custom_func_type,
-                                                 custom_command=True) if custom_func_name else None
-        _cli_generic_update_command(
-            self.command_loader,
-            '{} {}'.format(self.group_name, name),
-            getter_op=getter_op,
-            setter_op=setter_op,
+        getter_op_path = self._resolve_operation(merged_kwargs, getter_name, getter_type)
+        setter_op_path = self._resolve_operation(merged_kwargs, setter_name, setter_type)
+        custom_function_op_path = self._resolve_operation(merged_kwargs_custom, custom_func_name, custom_func_type,
+                                                          custom_command=True) if custom_func_name else None
+        command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
+        command_operation = GenericUpdateCommandOperation(
+            command_loader=self.command_loader,
+            getter_op_path=getter_op_path,
+            setter_op_path=setter_op_path,
             setter_arg_name=setter_arg_name,
-            custom_function_op=custom_func_op,
+            custom_function_op_path=custom_function_op_path,
             child_collection_prop_name=child_collection_prop_name,
             child_collection_key=child_collection_key,
             child_arg_name=child_arg_name,
-            **merged_kwargs)
+            **merged_kwargs
+        )
+        self.command_loader.add_cli_command(command_name,
+                                            command_operation=command_operation,
+                                            **merged_kwargs)
 
     def wait_command(self, name, getter_name='get', **kwargs):
         self._wait_command(name, getter_name=getter_name, custom_command=False, **kwargs)
@@ -1317,16 +1357,24 @@ class AzCommandGroup(CommandGroup):
         self._wait_command(name, getter_name=getter_name, getter_type=getter_type, **kwargs)
 
     def _wait_command(self, name, getter_name='get', getter_type=None, custom_command=False, **kwargs):
-        from azure.cli.core.commands.arm import _cli_wait_command
+        from azure.cli.core.commands.command_operation import WaitCommandOperation
         self._check_stale()
         merged_kwargs = self._flatten_kwargs(kwargs, get_command_type_kwarg(custom_command))
         self._apply_tags(merged_kwargs, kwargs, name)
 
         if getter_type:
             merged_kwargs = _merge_kwargs(getter_type.settings, merged_kwargs, CLI_COMMAND_KWARGS)
-        getter_op = self._resolve_operation(merged_kwargs, getter_name, getter_type, custom_command=custom_command)
-        _cli_wait_command(self.command_loader, '{} {}'.format(self.group_name, name), getter_op=getter_op,
-                          custom_command=custom_command, **merged_kwargs)
+        getter_op_path = self._resolve_operation(merged_kwargs, getter_name, getter_type, custom_command=custom_command)
+
+        command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
+        command_operation = WaitCommandOperation(
+            command_loader=self.command_loader,
+            op_path=getter_op_path,
+            **merged_kwargs
+        )
+        self.command_loader.add_cli_command(command_name,
+                                            command_operation=command_operation,
+                                            **merged_kwargs)
 
     def show_command(self, name, getter_name='get', **kwargs):
         self._show_command(name, getter_name=getter_name, custom_command=False, **kwargs)
@@ -1335,16 +1383,24 @@ class AzCommandGroup(CommandGroup):
         self._show_command(name, getter_name=getter_name, custom_command=True, **kwargs)
 
     def _show_command(self, name, getter_name='get', getter_type=None, custom_command=False, **kwargs):
-        from azure.cli.core.commands.arm import _cli_show_command
+        from azure.cli.core.commands.command_operation import ShowCommandOperation
         self._check_stale()
         merged_kwargs = self._flatten_kwargs(kwargs, get_command_type_kwarg(custom_command))
         self._apply_tags(merged_kwargs, kwargs, name)
 
         if getter_type:
             merged_kwargs = _merge_kwargs(getter_type.settings, merged_kwargs, CLI_COMMAND_KWARGS)
-        getter_op = self._resolve_operation(merged_kwargs, getter_name, getter_type, custom_command=custom_command)
-        _cli_show_command(self.command_loader, '{} {}'.format(self.group_name, name), getter_op=getter_op,
-                          custom_command=custom_command, **merged_kwargs)
+        op_path = self._resolve_operation(merged_kwargs, getter_name, getter_type, custom_command=custom_command)
+
+        command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
+        command_operation = ShowCommandOperation(
+            command_loader=self.command_loader,
+            op_path=op_path,
+            **merged_kwargs
+        )
+        self.command_loader.add_cli_command(command_name,
+                                            command_operation=command_operation,
+                                            **merged_kwargs)
 
     def _apply_tags(self, merged_kwargs, kwargs, command_name):
         # don't inherit deprecation or preview info from command group
