@@ -10,8 +10,8 @@ from azure.mgmt.msi import ManagedServiceIdentityClient
 from knack.util import CLIError
 
 
-def cf_compute_service(cli_ctx, *_):
-    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_COMPUTE)
+def get_container_service_client(cli_ctx, **_):
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_CONTAINERSERVICE)
 
 
 def cf_container_services(cli_ctx, *_):
@@ -26,10 +26,24 @@ def cf_agent_pools(cli_ctx, *_):
     return get_container_service_client(cli_ctx).agent_pools
 
 
+def cf_snapshots(cli_ctx, *_):
+    return get_container_service_client(cli_ctx).snapshots
+
+
+def get_osa_container_service_client(cli_ctx, **_):
+    from azure.mgmt.containerservice import ContainerServiceClient
+
+    return get_mgmt_service_client(cli_ctx, ContainerServiceClient, api_version='2019-09-30-preview')
+
+
 def cf_openshift_managed_clusters(cli_ctx, *_):
     return get_osa_container_service_client(cli_ctx).open_shift_managed_clusters
 
 
+def cf_compute_service(cli_ctx, *_):
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_COMPUTE)
+
+
 def cf_resource_groups(cli_ctx, subscription_id=None):
     return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_RESOURCES,
                                    subscription_id=subscription_id).resource_groups
@@ -45,15 +59,6 @@ def cf_container_registry_service(cli_ctx, subscription_id=None):
                                    subscription_id=subscription_id)
 
 
-def cf_snapshots_client(cli_ctx, subscription_id=None):
-    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_CONTAINERSERVICE,
-                                   subscription_id=subscription_id).snapshots
-
-
-def cf_snapshots(cli_ctx, *_):
-    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_CONTAINERSERVICE).snapshots
-
-
 def get_auth_management_client(cli_ctx, scope=None, **_):
     import re
 
@@ -67,16 +72,6 @@ def get_auth_management_client(cli_ctx, scope=None, **_):
     return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_AUTHORIZATION, subscription_id=subscription_id)
 
 
-def get_container_service_client(cli_ctx, **_):
-    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_CONTAINERSERVICE)
-
-
-def get_osa_container_service_client(cli_ctx, **_):
-    from azure.mgmt.containerservice import ContainerServiceClient
-
-    return get_mgmt_service_client(cli_ctx, ContainerServiceClient, api_version='2019-09-30-preview')
-
-
 def get_graph_rbac_management_client(cli_ctx, **_):
     from azure.cli.core.commands.client_factory import configure_common_settings
     from azure.cli.core._profile import Profile
