@@ -3,15 +3,7 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from distutils.version import StrictVersion  # pylint: disable=no-name-in-module,import-error
-
-# pylint: disable=no-name-in-module,import-error
-from azure.mgmt.containerservice.v2020_09_01.models import ManagedClusterLoadBalancerProfile
-from azure.mgmt.containerservice.v2020_09_01.models import ManagedClusterLoadBalancerProfileManagedOutboundIPs
-from azure.mgmt.containerservice.v2020_09_01.models import ManagedClusterLoadBalancerProfileOutboundIPPrefixes
-from azure.mgmt.containerservice.v2020_09_01.models import ManagedClusterLoadBalancerProfileOutboundIPs
-from azure.mgmt.containerservice.v2020_09_01.models import ResourceReference
-
+from distutils.version import StrictVersion
 from knack.log import get_logger
 
 logger = get_logger(__name__)
@@ -29,49 +21,65 @@ def set_load_balancer_sku(sku, kubernetes_version):
 
 
 def update_load_balancer_profile(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
-                                 outbound_ports, idle_timeout, profile):
+                                 outbound_ports, idle_timeout, profile, models):
     """parse and update an existing load balancer profile"""
     if not is_load_balancer_profile_provided(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
                                              outbound_ports, idle_timeout):
         return profile
     return configure_load_balancer_profile(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
-                                           outbound_ports, idle_timeout, profile)
+                                           outbound_ports, idle_timeout, profile, models)
 
 
 def create_load_balancer_profile(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
-                                 outbound_ports, idle_timeout):
+                                 outbound_ports, idle_timeout, models):
     """parse and build load balancer profile"""
     if not is_load_balancer_profile_provided(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
                                              outbound_ports, idle_timeout):
         return None
 
+    ManagedClusterLoadBalancerProfile = models.get("ManagedClusterLoadBalancerProfile")
     profile = ManagedClusterLoadBalancerProfile()
     return configure_load_balancer_profile(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes,
-                                           outbound_ports, idle_timeout, profile)
+                                           outbound_ports, idle_timeout, profile, models)
 
 
 def configure_load_balancer_profile(managed_outbound_ip_count, outbound_ips, outbound_ip_prefixes, outbound_ports,
-                                    idle_timeout, profile):
+                                    idle_timeout, profile, models):
     """configure a load balancer with customer supplied values"""
     if not profile:
         return profile
 
-    outbound_ip_resources = _get_load_balancer_outbound_ips(outbound_ips)
-    outbound_ip_prefix_resources = _get_load_balancer_outbound_ip_prefixes(outbound_ip_prefixes)
+    outbound_ip_resources = _get_load_balancer_outbound_ips(outbound_ips, models)
+    outbound_ip_prefix_resources = _get_load_balancer_outbound_ip_prefixes(
+        outbound_ip_prefixes, models)
 
     if managed_outbound_ip_count or outbound_ip_resources or outbound_ip_prefix_resources:
-        profile.managed_outbound_ips = None
-        profile.outbound_ips = None
+        # ips -> i_ps due to track 2 naming issue
+        profile.managed_outbound_i_ps = None
+        # ips -> i_ps due to track 2 naming issue
+        profile.outbound_i_ps = None
         profile.outbound_ip_prefixes = None
         if managed_outbound_ip_count:
-            profile.managed_outbound_ips = ManagedClusterLoadBalancerProfileManagedOutboundIPs(
+            ManagedClusterLoadBalancerProfileManagedOutboundIPs = models.get(
+                "ManagedClusterLoadBalancerProfileManagedOutboundIPs"
+            )
+            # ips -> i_ps due to track 2 naming issue
+            profile.managed_outbound_i_ps = ManagedClusterLoadBalancerProfileManagedOutboundIPs(
                 count=managed_outbound_ip_count
             )
         if outbound_ip_resources:
-            profile.outbound_ips = ManagedClusterLoadBalancerProfileOutboundIPs(
-                public_ips=outbound_ip_resources
+            ManagedClusterLoadBalancerProfileOutboundIPs = models.get(
+                "ManagedClusterLoadBalancerProfileOutboundIPs"
+            )
+            # ips -> i_ps due to track 2 naming issue
+            profile.outbound_i_ps = ManagedClusterLoadBalancerProfileOutboundIPs(
+                # ips -> i_ps due to track 2 naming issue
+                public_i_ps=outbound_ip_resources
             )
         if outbound_ip_prefix_resources:
+            ManagedClusterLoadBalancerProfileOutboundIPPrefixes = models.get(
+                "ManagedClusterLoadBalancerProfileOutboundIPPrefixes"
+            )
             profile.outbound_ip_prefixes = ManagedClusterLoadBalancerProfileOutboundIPPrefixes(
                 public_ip_prefixes=outbound_ip_prefix_resources
             )
@@ -91,20 +99,24 @@ def is_load_balancer_profile_provided(managed_outbound_ip_count, outbound_ips, i
                 idle_timeout])
 
 
-def _get_load_balancer_outbound_ips(load_balancer_outbound_ips):
+def _get_load_balancer_outbound_ips(load_balancer_outbound_ips, models):
     """parse load balancer profile outbound IP ids and return an array of references to the outbound IP resources"""
     load_balancer_outbound_ip_resources = None
+    ResourceReference = models.get("ResourceReference")
     if load_balancer_outbound_ips:
         load_balancer_outbound_ip_resources = \
-            [ResourceReference(id=x.strip()) for x in load_balancer_outbound_ips.split(',')]
+            [ResourceReference(id=x.strip())
+             for x in load_balancer_outbound_ips.split(',')]
     return load_balancer_outbound_ip_resources
 
 
-def _get_load_balancer_outbound_ip_prefixes(load_balancer_outbound_ip_prefixes):
+def _get_load_balancer_outbound_ip_prefixes(load_balancer_outbound_ip_prefixes, models):
     """parse load balancer profile outbound IP prefix ids and return an array \
     of references to the outbound IP prefix resources"""
     load_balancer_outbound_ip_prefix_resources = None
+    ResourceReference = models.get("ResourceReference")
     if load_balancer_outbound_ip_prefixes:
         load_balancer_outbound_ip_prefix_resources = \
-            [ResourceReference(id=x.strip()) for x in load_balancer_outbound_ip_prefixes.split(',')]
+            [ResourceReference(id=x.strip())
+             for x in load_balancer_outbound_ip_prefixes.split(',')]
     return load_balancer_outbound_ip_prefix_resources
