@@ -347,8 +347,10 @@ def get_profile_username():
     return user
 
 
-def get_sku_to_use(src_dir, html=False, sku=None, runtime=None):
+def get_sku_to_use(src_dir, html=False, sku=None, runtime=None, app_service_environment=None):
     if sku is None:
+        if app_service_environment:
+            return 'I1v2'
         if runtime:  # user overrided language detection by specifiying runtime
             return 'F1'
         lang_details = get_lang_from_content(src_dir, html)
