@@ -128,6 +128,41 @@ class BotTests(ScenarioTest):
 
         self.cmd('az bot delete -g {rg} -n {botname}')
 
+    @ResourceGroupPreparer(random_name_length=20)
+    def test_botservice_registration_bot_create_specific_location(self, resource_group):
+        locations = ['global', 'westus', 'westeurope']
+        for location in locations:
+            self.kwargs.update({
+                'botname': self.create_random_name(prefix='cli', length=10),
+                'description': 'description1',
+                'endpoint': 'https://www.google.com/api/messages',
+                'app_id': str(uuid.uuid4()),
+                'password': str(uuid.uuid4()),
+                'location': location,
+            })
+
+            self.cmd(
+                'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p '
+                '{password} --tags key1=value1 -l {location}',
+                checks=[
+                    self.check('name', '{botname}'),
+                    self.check('properties.description', '{description}'),
+                    self.check('resourceGroup', '{rg}'),
+                    self.check('location', '{location}'),
+                    self.check('tags.key1', 'value1')
+                ])
+
+            self.cmd('az bot show -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}')
+            ])
+
+            self.cmd('az bot update --description description2 -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}'),
+                self.check('properties.description', 'description2')
+            ])
+
+            self.cmd('az bot delete -g {rg} -n {botname}')
+
     @ResourceGroupPreparer(random_name_length=20)
     def test_botservice_create_should_be_idempotent_and_return_existing_bot_info(self, resource_group):
         self.kwargs.update({
