@@ -16,9 +16,9 @@ class CognitiveServicesCustomDomainTests(ScenarioTest):
 
         self.kwargs.update({
             'sname': sname,
-            'kind': 'Face',
+            'kind': 'FormRecognizer',
             'sku': 'S0',
-            'location': 'westus',
+            'location': 'centraluseuap',
             'customdomain': customdomain,
         })
 
@@ -28,26 +28,28 @@ class CognitiveServicesCustomDomainTests(ScenarioTest):
                  checks=[self.check('name', '{sname}'),
                          self.check('location', '{location}'),
                          self.check('sku.name', '{sku}'),
-                         self.check('properties.provisioningState', 'Succeeded'),
                          self.check('properties.customSubDomainName', '{customdomain}')])
 
         # delete the cognitive services account
         ret = self.cmd('az cognitiveservices account delete -n {sname} -g {rg}')
         self.assertEqual(ret.exit_code, 0)
 
+        self.kwargs.update({
+            'sname': self.create_random_name(prefix='cs_cli_test_', length=16),
+            'customdomain': self.create_random_name(prefix='csclitest', length=16),
+        })
+
         # test to create cognitive services account
         self.cmd('az cognitiveservices account create -n {sname} -g {rg} --kind {kind} --sku {sku} -l {location} --yes',
                  checks=[self.check('name', '{sname}'),
                          self.check('location', '{location}'),
-                         self.check('sku.name', '{sku}'),
-                         self.check('properties.provisioningState', 'Succeeded')])
+                         self.check('sku.name', '{sku}')])
 
         # test to create cognitive services account
         self.cmd('az cognitiveservices account update -n {sname} -g {rg} --custom-domain {customdomain}',
                  checks=[self.check('name', '{sname}'),
                          self.check('location', '{location}'),
                          self.check('sku.name', '{sku}'),
-                         self.check('properties.provisioningState', 'Succeeded'),
                          self.check('properties.customSubDomainName', '{customdomain}')])
 
         # delete the cognitive services account
