@@ -146,7 +146,7 @@ examples:
 
 helps['eventhubs eventhub list'] = """
 type: command
-short-summary: List the EventHub by Namepsace
+short-summary: List the EventHub by Namespace
 examples:
   - name: Get the Eventhubs by Namespace.
     text: az eventhubs eventhub list --resource-group myresourcegroup --namespace-name mynamespace
@@ -343,6 +343,8 @@ short-summary: Creates the EventHubs Namespace
 examples:
   - name: Creates a new namespace.
     text: az eventhubs namespace create --resource-group myresourcegroup --name mynamespace --location westus --tags tag1=value1 tag2=value2 --sku Standard --enable-auto-inflate --maximum-throughput-units 20
+  - name: Create a new namespace with Identity and Encryption enabled.
+    text: az eventhubs namespace create --resource-group myresourcegroup --name mynamespace --location westus --sku Premium --mi-user-assigned /subscriptions/{subscriptionId}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName --encryption-config key-name=key1 key-vault-uri=https://mykeyvault.vault.azure.net/ user-assigned-identity=/subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName --encryption-config key-name=key1 key-vault-uri=https://mykeyvault.vault.azure.net/ user-assigned-identity=/subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName
 """
 
 helps['eventhubs namespace delete'] = """
@@ -496,3 +498,148 @@ helps['eventhubs cluster wait'] = """
 type: command
 short-summary: Place the CLI in a waiting state until a condition of the Cluster operation is completed.
 """
+
+helps['eventhubs namespace private-endpoint-connection'] = """
+type: group
+short-summary: Manage eventhubs namespace private endpoint connection.
+"""
+
+helps['eventhubs namespace private-endpoint-connection approve'] = """
+type: command
+short-summary: Approve a private endpoint connection request for eventhubs namesapce.
+examples:
+  - name: Approve a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        az eventhubs namespace private-endpoint-connection approve --id "/subscriptions/0000-0000-0000-0000/resourceGroups/MyResourceGroup/providers/Microsoft.Eventhub/namesapces/mynamepsace/privateEndpointConnections/mynamespace.b56b5a95-0588-4f8b-b348-15db61590a6c"
+  - name: Approve a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        id = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].id")
+        az eventhubs namespace private-endpoint-connection approve --id $id
+  - name: Approve a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        az eventhubs namespace private-endpoint-connection approve -g myRg --namespace-name mynamespace --name myconnection
+  - name: Approve a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        name = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].name")
+        az eventhubs namespace private-endpoint-connection approve -g myRg --namespace-name mynamespace --name $name
+"""
+
+helps['eventhubs namespace private-endpoint-connection delete'] = """
+type: command
+short-summary: Delete a private endpoint connection request for eventhubs namespace.
+examples:
+  - name: Delete a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        az eventhubs namespace private-endpoint-connection delete --id "/subscriptions/0000-0000-0000-0000/resourceGroups/MyResourceGroup/providers/Microsoft.EventHub/namespaces/mynamespace/privateEndpointConnections/mynamespace.b56b5a95-0588-4f8b-b348-15db61590a6c"
+  - name: Delete a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        id = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].id")
+        az eventhubs namespace private-endpoint-connection delete --id $id
+  - name: Delete a private endpoint connection request for eventhubs namespace using account name and connection name.
+    text: |
+        az eventhubs namespace private-endpoint-connection delete -g myRg --namespace-name mynamespace --name myconnection
+  - name: Delete a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        name = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].name")
+        az eventhubs namespace private-endpoint-connection delete -g myRg --namespace-name mynamespace --name $name
+"""
+
+helps['eventhubs namespace private-endpoint-connection reject'] = """
+type: command
+short-summary: Reject a private endpoint connection request for eventhubs namespace.
+examples:
+  - name: Reject a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        az eventhubs namespace private-endpoint-connection reject --id "/subscriptions/0000-0000-0000-0000/resourceGroups/MyResourceGroup/providers/Microsoft.EventHub/namespaces/mynamespace/privateEndpointConnections/mynamespace.b56b5a95-0588-4f8b-b348-15db61590a6c"
+  - name: Reject a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        id = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].id")
+        az eventhubs namespace private-endpoint-connection reject --id $id
+  - name: Reject a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        az eventhubs namespace private-endpoint-connection reject -g myRg --namespace-name mynamespace --name myconnection
+  - name: Reject a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        name = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].name")
+        az eventhubs namespace private-endpoint-connection reject -g myRg --namespace-name mynamespace --name $name
+"""
+
+helps['eventhubs namespace private-endpoint-connection show'] = """
+type: command
+short-summary: Show details of a private endpoint connection request for eventhubs namespace.
+examples:
+  - name: Show details of a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        az eventhubs namespace private-endpoint-connection show --id "/subscriptions/0000-0000-0000-0000/resourceGroups/MyResourceGroup/providers/Microsoft.EventHub/namespaces/mynamespace/privateEndpointConnections/mynamespace.b56b5a95-0588-4f8b-b348-15db61590a6c"
+  - name: Show details of a private endpoint connection request for eventhubs namespace by ID.
+    text: |
+        id = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].id")
+        az eventhubs namespace private-endpoint-connection show --id $id
+  - name: Show details of a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        az eventhubs namespace private-endpoint-connection show -g myRg --namespace-name mynamespace --name myconnection
+  - name: Show details of a private endpoint connection request for eventhubs namespace using namespace name and connection name.
+    text: |
+        name = (az eventhubs namespace show -n mynamespace --query "privateEndpointConnections[0].name")
+        az eventhubs namespace private-endpoint-connection show -g myRg --namespace-name mynamespace --name $name
+"""
+
+helps['eventhubs namespace private-link-resource'] = """
+type: group
+short-summary: Manage eventhubs namespace private link resources.
+"""
+
+helps['eventhubs namespace private-link-resource show'] = """
+type: command
+short-summary: Get the private link resources that need to be created for a eventhubs namespace.
+examples:
+  - name: Get the private link resources that need to be created for a eventhubs namespace.
+    text: |
+        az eventhubs namespace private-link-resource show --namespace-name mynamespace -g MyResourceGroup
+"""
+
+helps['eventhubs namespace encryption'] = """
+type: group
+short-summary: Manage eventhubs namespace encryption properties.
+"""
+
+helps['eventhubs namespace encryption add'] = """
+type: command
+short-summary: Add Encryption properties to a namespace.
+examples:
+  - name: Set 2 different encryption properties for a namespace that has User Assigned Identity already enabled
+    text: |
+        az eventhubs namespace encryption add --namespace-name mynamespace -g MyResourceGroup --encryption-config key-name=key1 key-vault-uri=https://mykeyvault.vault.azure.net/ user-assigned-identity=/subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName --encryption-config key-name=key1 key-vault-uri=https://mykeyvault.vault.azure.net/ user-assigned-identity=/subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName2
+"""
+
+helps['eventhubs namespace encryption remove'] = """
+type: command
+short-summary: Remove one or more Encryption properties from a namespace.
+examples:
+  - name: Remove encryption properties for a namespace that has User Assigned Identity already enabled
+    text: |
+        az eventhubs namespace encryption remove --namespace-name mynamespace -g MyResourceGroup --encryption-config key-name=key1 key-vault-uri=https://mykeyvault.vault.azure.net/ user-assigned-identity=/subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName
+"""
+
+helps['eventhubs namespace identity'] = """
+type: group
+short-summary: Manage eventhubs namespace identity.
+"""
+
+helps['eventhubs namespace identity assign'] = """
+type: command
+short-summary: Assign System or User or System,User assigned identities to a namespace
+examples:
+  - name: Assign system assigned and user assigned identity to a namespace. (give a list of identity id's for --user-assigned)
+    text: |
+        az eventhubs namespace identity assign --namespace-name mynamespace -g MyResourceGroup --system-assigned --user-assigned /subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName /subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName2
+"""
+
+helps['eventhubs namespace identity remove'] = """
+type: command
+short-summary: Remove System or User or System,User assigned identities from a namespace
+examples:
+  - name: Remove system assigned and a user assigned identity from a namespace. (give a list of identity id's for --user-assigned)
+    text: |
+        az eventhubs namespace identity remove --namespace-name mynamespace -g MyResourceGroup --system-assigned --user-assigned /subscriptions/{subscriptionId}}/resourceGroups/{resourcegroup}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/MSIName
+"""
