@@ -18,56 +18,6 @@ type: group
 short-summary: Manage Azure IoT Hub Device Provisioning Service.
 """
 
-helps['iot dps access-policy'] = """
-type: group
-short-summary: Manage shared access policies for an Azure IoT Hub Device Provisioning Service instance.
-"""
-
-helps['iot dps access-policy create'] = """
-type: command
-short-summary: Create a new shared access policy in an Azure IoT Hub Device Provisioning Service instance.
-examples:
-  - name: Create a new shared access policy in an Azure IoT Hub Device Provisioning Service instance with EnrollmentRead right
-    text: >
-        az iot dps access-policy create --dps-name MyDps --resource-group MyResourceGroup --name MyPolicy --rights EnrollmentRead
-"""
-
-helps['iot dps access-policy delete'] = """
-type: command
-short-summary: Delete a shared access policies in an Azure IoT Hub Device Provisioning Service instance.
-examples:
-  - name: Delete shared access policy 'MyPolicy' in the Azure IoT Hub Device Provisioning Service instance 'MyDps'
-    text: >
-        az iot dps access-policy delete --dps-name MyDps --resource-group MyResourceGroup --name MyPolicy
-"""
-
-helps['iot dps access-policy list'] = """
-type: command
-short-summary: List all shared access policies in an Azure IoT Hub Device Provisioning Service instance.
-examples:
-  - name: List all shared access policies in the Azure IoT Hub Device Provisioning Service instance 'MyDps'
-    text: >
-        az iot dps access-policy list --dps-name MyDps --resource-group MyResourceGroup
-"""
-
-helps['iot dps access-policy show'] = """
-type: command
-short-summary: Show details of a shared access policies in an Azure IoT Hub Device Provisioning Service instance.
-examples:
-  - name: Show details of shared access policy 'MyPolicy' in the Azure IoT Hub Device Provisioning Service instance 'MyDps'
-    text: >
-        az iot dps access-policy show --dps-name MyDps --resource-group MyResourceGroup --name MyPolicy
-"""
-
-helps['iot dps access-policy update'] = """
-type: command
-short-summary: Update a shared access policy in an Azure IoT Hub Device Provisioning Service instance.
-examples:
-  - name: Update shared access policy 'MyPolicy' in an Azure IoT Hub Device Provisioning Service instance with EnrollmentWrite right
-    text: >
-        az iot dps access-policy update --dps-name MyDps --resource-group MyResourceGroup --name MyPolicy --rights EnrollmentWrite
-"""
-
 helps['iot dps policy'] = """
 type: group
 short-summary: Manage shared access policies for an Azure IoT Hub Device Provisioning Service instance.
