@@ -4,6 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 from enum import Enum
+from knack.log import get_logger
 from knack.util import CLIError
 
 from azure.cli.core.azclierror import RequiredArgumentMissingError
@@ -11,6 +12,8 @@ from azure.cli.core.commands import CliCommandType
 from azure.cli.core.profiles import get_api_version, ResourceType
 from azure.cli.core._profile import Profile
 
+logger = get_logger(__name__)
+
 
 class Clients(str, Enum):
     vaults = 'vaults'
@@ -140,6 +143,7 @@ def keyvault_mgmt_client_factory(resource_type, client_name):
     def _keyvault_mgmt_client_factory(cli_ctx, _):
         from azure.cli.core.commands.client_factory import get_mgmt_service_client
         return getattr(get_mgmt_service_client(cli_ctx, resource_type), client_name)
+
     return _keyvault_mgmt_client_factory
 
 
@@ -162,8 +166,6 @@ def keyvault_data_plane_factory(cli_ctx, *_):
         verify = not should_disable_connection_verify()
         client._client.config.connection.verify = verify
     else:
-        from knack.log import get_logger
-        logger = get_logger(__name__)
         logger.info('Could not find the configuration object to turn off the verification if needed')
 
     return client
@@ -179,6 +181,7 @@ def keyvault_private_data_plane_factory_v7_2_preview(cli_ctx, _):
     def get_token(server, resource, scope):  # pylint: disable=unused-argument
         return Profile(cli_ctx=cli_ctx).get_raw_token(resource=resource,
                                                       subscription=cli_ctx.data.get('subscription_id'))[0]
+
     client = KeyVaultClient(KeyVaultAuthentication(get_token), api_version=version)
 
     # HACK, work around the fact that KeyVault library does't take confiuration object on constructor
@@ -188,8 +191,6 @@ def keyvault_private_data_plane_factory_v7_2_preview(cli_ctx, _):
         verify = not should_disable_connection_verify()
         client._client.config.connection.verify = verify
     else:
-        from knack.log import get_logger
-        logger = get_logger(__name__)
         logger.info('Could not find the configuration object to turn off the verification if needed')
 
     return client
@@ -218,10 +219,15 @@ def data_plane_azure_keyvault_key_client(cli_ctx, command_args):
 
     vault_url, credential, version = _prepare_data_plane_azure_keyvault_client(
         cli_ctx, command_args, ResourceType.DATA_KEYVAULT_KEYS)
+    is_hsm = command_args.get('hsm_name', None) is not None
+    if not is_hsm and command_args.get('identifier', None) is not None:
+        is_hsm = 'managedhsm' in command_args.get('identifier')
+    if is_hsm and ('key rotate' in cli_ctx.data['command'] or 'key rotation-policy' in cli_ctx.data['command']):
+        logger.warning("This command is in preview and under development.")
     command_args.pop('hsm_name', None)
     command_args.pop('vault_base_url', None)
     command_args.pop('identifier', None)
-    api_version = '7.3-preview' if not is_azure_stack_profile(cmd=None, cli_ctx=cli_ctx) else '2016-10-01'
+    api_version = '7.3' if not is_azure_stack_profile(cmd=None, cli_ctx=cli_ctx) else '2016-10-01'
     return KeyClient(
         vault_url=vault_url, credential=credential, api_version=api_version or version)
 
