@@ -16,7 +16,8 @@ from ._client_factory import (
     backups_mgmt_client_factory,
     backup_policies_mgmt_client_factory,
     vaults_mgmt_client_factory,
-    subvolumes_mgmt_client_factory)
+    subvolumes_mgmt_client_factory,
+    volume_groups_mgmt_client_factory)
 from ._exception_handler import netappfiles_exception_handler
 
 
@@ -91,6 +92,13 @@ def load_command_table(self, _):
     )
     load_subvolumes_command_groups(self, netappfiles_subvolumes_sdk)
 
+    netappfiles_volume_groups_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.netapp.operations._volume_groups_operations#VolumeGroupsOperations.{}',
+        client_factory=volume_groups_mgmt_client_factory,
+        exception_handler=netappfiles_exception_handler
+    )
+    load_volume_groups_command_groups(self, netappfiles_volume_groups_sdk)
+
     with self.command_group('netappfiles', is_preview=False):
         pass
 
@@ -303,3 +311,16 @@ def load_subvolumes_command_groups(self, netappfiles_subvolumes_sdk):
 
     with self.command_group('netappfiles subvolume metadata', netappfiles_subvolumes_sdk) as g:
         g.show_command('show', 'begin_get_metadata')
+
+
+def load_volume_groups_command_groups(self, netappfiles_volume_groups_sdk):
+    with self.command_group('netappfiles volume-group', netappfiles_volume_groups_sdk) as g:
+        g.show_command('show', 'get')
+        g.command('list', 'list_by_net_app_account')
+        g.custom_command('create', 'create_volume_group',
+                         client_factory=volume_groups_mgmt_client_factory,
+                         supports_no_wait=True,
+                         doc_string_source='azure.mgmt.netapp.models#VolumeGroupDetails',
+                         exception_handler=netappfiles_exception_handler)
+        g.command('delete', 'begin_delete', confirmation=True)
+        g.wait_command('wait')
