@@ -4,8 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer
-LOCATION = "southcentralusstage"
-VAULT_LOCATION = "southcentralus"
+LOCATION = "eastus2"
 
 # No tidy up of tests required. The resource group is automatically removed
 
