@@ -4,6 +4,7 @@
 # --------------------------------------------------------------------------------------------
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer
 from azure.cli.testsdk.decorators import serial_test
+from knack.util import CLIError
 
 POOL_DEFAULT = "--service-level 'Premium' --size 4"
 VOLUME_DEFAULT = "--service-level 'Premium' --usage-threshold 100"
@@ -177,7 +178,7 @@ class AzureNetAppFilesSnapshotServiceScenarioTest(ScenarioTest):
         assert snapshot_from_id['name'] == account_name + '/' + pool_name + '/' + volume_name + '/' + snapshot_name
 
     @ResourceGroupPreparer(name_prefix='cli_netappfiles_test_snapshot_', additional_tags={'owner': 'cli_test'})
-    def test_restore_file(self):
+    def test_restore_file_returns_not_found(self):
         # create volume
         account_name = self.create_random_name(prefix='cli-acc-', length=24)
         pool_name = self.create_random_name(prefix='cli-pool-', length=24)
@@ -192,10 +193,6 @@ class AzureNetAppFilesSnapshotServiceScenarioTest(ScenarioTest):
 
         snapshot_file_path = "'/snap_file_path_1.txt' '/snap_file_path_2.txt'"
 
-        self.cmd("az netappfiles snapshot restore-files -g {rg} -a %s -p %s -v %s -s %s --file-paths %s" %
-                 (account_name, pool_name, volume_name, snapshot_name, snapshot_file_path))
-
-        snapshot = self.cmd("az netappfiles snapshot show -g {rg} -a %s -p %s -v %s -s %s" %
-                            (account_name, pool_name, volume_name, snapshot_name)).get_output_in_json()
-
-        assert snapshot['provisioningState'] == 'Succeeded'
+        with self.assertRaisesRegex(CLIError, "The specified filePath /snap_file_path_1.txt does not exist"):
+            self.cmd("az netappfiles snapshot restore-files -g {rg} -a %s -p %s -v %s -s %s --file-paths %s" %
+                     (account_name, pool_name, volume_name, snapshot_name, snapshot_file_path))
