@@ -4,6 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 from azure.cli.testsdk import (ScenarioTest, ResourceGroupPreparer, StorageAccountPreparer)
+from azure.cli.testsdk.scenario_tests.decorators import AllowLargeResponse
 
 
 class NWFlowLogScenarioTest(ScenarioTest):
@@ -59,6 +60,7 @@ class NWFlowLogScenarioTest(ScenarioTest):
 
     @ResourceGroupPreparer(name_prefix='test_nw_flow_log_', location='westus')
     @StorageAccountPreparer(name_prefix='testflowlog', location='westus', kind='StorageV2')
+    @AllowLargeResponse(1024)
     def test_nw_flow_log_delete(self, resource_group, resource_group_location, storage_account):
         self.kwargs.update({
             'rg': resource_group,
@@ -103,6 +105,7 @@ class NWFlowLogScenarioTest(ScenarioTest):
 
     @ResourceGroupPreparer(name_prefix='test_nw_flow_log_', location='westus')
     @StorageAccountPreparer(name_prefix='testflowlog', location='westus', kind='StorageV2')
+    @AllowLargeResponse(1024)
     def test_nw_flow_log_show(self, resource_group, resource_group_location, storage_account):
         """
         This test is used to demonstrate different outputs between the new and deprecating parameters
