@@ -6,6 +6,7 @@
 # AZURE CLI RBAC TEST DEFINITIONS
 import json
 import os
+import sys
 import tempfile
 import time
 import datetime
@@ -33,7 +34,7 @@ class RbacSPSecretScenarioTest(RoleScenarioTest):
         self.kwargs['display_name_new'] = self.create_random_name('cli-test-sp', 15)
 
         try:
-            sp_info = self.cmd('ad sp create-for-rbac -n {display_name} --skip-assignment').get_output_in_json()
+            sp_info = self.cmd('ad sp create-for-rbac -n {display_name}').get_output_in_json()
             self.assertTrue(sp_info['displayName'] == sp_name)
             self.kwargs['app_id'] = sp_info['appId']
 
@@ -51,7 +52,7 @@ class RbacSPSecretScenarioTest(RoleScenarioTest):
 
         self.kwargs['display_name'] = resource_group
         try:
-            result = self.cmd('ad sp create-for-rbac -n {display_name} --skip-assignment',
+            result = self.cmd('ad sp create-for-rbac -n {display_name}',
                               checks=self.check('displayName', '{display_name}')).get_output_in_json()
             self.kwargs['app_id'] = result['appId']
         finally:
@@ -64,49 +65,76 @@ class RbacSPSecretScenarioTest(RoleScenarioTest):
         subscription_id = self.get_subscription_id()
         self.kwargs.update({
             'sub': subscription_id,
-            'scope': '/subscriptions/{}'.format(subscription_id),
+            'scope': f'/subscriptions/{subscription_id}/resourceGroups/{resource_group}',
+            'role': 'Reader',
             'display_name': resource_group
         })
 
         try:
             with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                result = self.cmd('ad sp create-for-rbac -n {display_name} --scopes {scope} {scope}/resourceGroups/{rg}',
+                result = self.cmd('ad sp create-for-rbac -n {display_name} '
+                                  '--scopes {scope} --role {role}',
                                   checks=self.check('displayName', '{display_name}')).get_output_in_json()
                 self.kwargs['app_id'] = result['appId']
-                self.cmd('role assignment list --assignee {app_id} --scope {scope}',
-                         checks=self.check("length([])", 1))
                 self.cmd('role assignment list --assignee {app_id} -g {rg}',
-                         checks=self.check("length([])", 1))
+                         checks=[
+                             self.check("length([])", 1),
+                             self.check("[0].roleDefinitionName", '{role}'),
+                             self.check("[0].scope", '{scope}')
+                         ])
                 self.cmd('role assignment delete --assignee {app_id} -g {rg}',
                          checks=self.is_empty())
-                self.cmd('role assignment delete --assignee {app_id}',
-                         checks=self.is_empty())
         finally:
             self.cmd('ad app delete --id {app_id}')
 
+    def test_create_for_rbac_argument_error(self):
+
+        self.kwargs.update({
+            'scope': '/subscriptions/00000000-0000-0000-0000-000000000000',
+            'role': 'Reader',
+        })
+
+        from azure.cli.core.azclierror import ArgumentUsageError
+
+        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
+            self.cmd('ad sp create-for-rbac --scopes {scope}')
+
+        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
+            self.cmd('ad sp create-for-rbac --role {role}')
+
 
 class RbacSPCertScenarioTest(RoleScenarioTest):
-    @ResourceGroupPreparer(name_prefix='cli_create_rbac_sp_with_cert')
-    def test_create_for_rbac_with_cert_with_assignment(self, resource_group):
 
-        subscription_id = self.get_subscription_id()
+    @ResourceGroupPreparer(name_prefix='cli_create_rbac_sp_with_cert')
+    def test_create_for_rbac_with_cert_no_assignment(self, resource_group):
+
         self.kwargs.update({
-            'sub': subscription_id,
-            'scope': '/subscriptions/{}'.format(subscription_id),
-            'display_name': resource_group
+            'display_name': resource_group,
         })
 
         try:
             with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                result = self.cmd('ad sp create-for-rbac -n {display_name} --scopes {scope} {scope}/resourceGroups/{rg} --create-cert',
+                result = self.cmd('ad sp create-for-rbac -n {display_name} --create-cert',
                                   checks=self.check('displayName', '{display_name}')).get_output_in_json()
                 self.kwargs['app_id'] = result['appId']
 
                 self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
+
+                # On Linux or MacOS, check the cert file is a regular file (S_IFREG 0100000) with permission 600
+                # https://manpages.ubuntu.com/manpages/focal/man7/inode.7.html
+                # Windows doesn't have the Linux permission concept.
+                if sys.platform != 'win32':
+                    assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
+
                 os.remove(result['fileWithCertAndPrivateKey'])
+
                 result = self.cmd('ad sp credential reset -n {app_id} --create-cert',
                                   checks=self.check('name', '{app_id}')).get_output_in_json()
                 self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
+
+                if sys.platform != 'win32':
+                    assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
+
                 os.remove(result['fileWithCertAndPrivateKey'])
         finally:
             self.cmd('ad app delete --id {app_id}',
@@ -133,7 +161,7 @@ class RbacSPKeyVaultScenarioTest2(ScenarioTest):
         try:
             with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
                 try:
-                    result = self.cmd('ad sp create-for-rbac --scopes {scope}/resourceGroups/{rg} --create-cert '
+                    result = self.cmd('ad sp create-for-rbac --create-cert '
                                       '--keyvault {kv} --cert {cert} -n {display_name}').get_output_in_json()
                     self.kwargs['app_id'] = result['appId']
                 except KeyVaultErrorException:
@@ -173,7 +201,7 @@ class RbacSPKeyVaultScenarioTest(ScenarioTest):
             self.cmd('keyvault certificate create --vault-name {kv} -n {cert} -p "{policy}" --validity 24')
             with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
                 result = self.cmd('ad sp create-for-rbac -n {display_name} --keyvault {kv} '
-                                  '--cert {cert} --scopes {scope}/resourceGroups/{rg}').get_output_in_json()
+                                  '--cert {cert}').get_output_in_json()
                 self.kwargs['app_id'] = result['appId']
             self.cmd('ad sp credential reset -n {app_id} --keyvault {kv} --cert {cert}')
         finally:
@@ -187,7 +215,7 @@ class RbacSPKeyVaultScenarioTest(ScenarioTest):
         try:
             self.cmd('keyvault certificate create --vault-name {kv} -n {cert} -p "{policy}" --validity 6')
             with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                result = self.cmd('ad sp create-for-rbac --scopes {scope}/resourceGroups/{rg} --keyvault {kv} '
+                result = self.cmd('ad sp create-for-rbac --keyvault {kv} '
                                   '--cert {cert} -n {display_name2}').get_output_in_json()
                 self.kwargs['app_id2'] = result['appId']
             self.cmd('ad sp credential reset -n {app_id2} --keyvault {kv} --cert {cert}')
@@ -421,7 +449,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
 
             # Service Principal
             self.kwargs['sp_name'] = self.create_random_name('sp', 15)
-            result = self.cmd('ad sp create-for-rbac --skip-assignment --name {sp_name}').get_output_in_json()
+            result = self.cmd('ad sp create-for-rbac --name {sp_name}').get_output_in_json()
             self.kwargs['app_id'] = result['appId']
             result = self.cmd('ad sp show --id {app_id}').get_output_in_json()
             try:
