@@ -1,18 +1,42 @@
+import json
+import string
+
 # --------------------------------------------------------------------------------------------
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
 from azure.mgmt.security.models import (SecurityContact,
-                                        AutoProvision,
+                                        AutoProvisioningSetting,
                                         SecurityAssessment,
                                         SecurityAssessmentMetadata,
                                         AzureResourceDetails,
                                         AssessmentStatus,
                                         IoTSecuritySolutionModel,
-                                        UpdateIotSecuritySolutionData)
+                                        UpdateIotSecuritySolutionData,
+                                        Pricing,
+                                        WorkspaceSetting,
+                                        AdvancedThreatProtectionSetting,
+                                        RuleResultsInput,
+                                        RulesResultsInput,
+                                        AlertSyncSettings,
+                                        DataExportSettings,
+                                        Automation,
+                                        AutomationScope,
+                                        AutomationSource,
+                                        AutomationActionWorkspace,
+                                        AutomationActionLogicApp,
+                                        AutomationActionEventHub,
+                                        AutomationRuleSet,
+                                        AutomationTriggeringRule)
+from azure.mgmt.security.models._security_center_enums import Enum69
+from azure.cli.core.commands.client_factory import get_subscription_id
+from azure.cli.core.azclierror import MutuallyExclusiveArgumentError
 from msrestazure.tools import resource_id
 from msrestazure.azure_exceptions import CloudError
+from ._utils import (
+    run_cli_cmd
+)
 
 # --------------------------------------------------------------------------------------------
 # Security Tasks
@@ -22,7 +46,7 @@ from msrestazure.azure_exceptions import CloudError
 def list_security_tasks(client, resource_group_name=None):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     if resource_group_name:
         return client.tasks.list_by_resource_group(resource_group_name)
@@ -33,7 +57,7 @@ def list_security_tasks(client, resource_group_name=None):
 def get_security_task(client, resource_name, resource_group_name=None):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     if resource_group_name:
         return client.tasks.get_resource_group_level_task(resource_group_name, resource_name)
@@ -48,12 +72,12 @@ def get_security_task(client, resource_name, resource_group_name=None):
 def list_security_alerts(client, resource_group_name=None, location=None):
 
     if location:
-        client.config.asc_location = location
+        client._config.asc_location = location  # pylint: disable=protected-access
 
         if resource_group_name:
-            return client.list_resource_group_level_alerts_by_region(resource_group_name)
+            return client.list_resource_group_level_by_region(resource_group_name)
 
-        return client.list_subscription_level_alerts_by_region()
+        return client.list_subscription_level_by_region()
 
     if resource_group_name:
         return client.list_by_resource_group(resource_group_name)
@@ -63,30 +87,30 @@ def list_security_alerts(client, resource_group_name=None, location=None):
 
 def get_security_alert(client, location, resource_name, resource_group_name=None):
 
-    client.config.asc_location = location
+    client._config.asc_location = location  # pylint: disable=protected-access
 
     if resource_group_name:
-        return client.get_resource_group_level_alerts(resource_name, resource_group_name)
+        return client.get_resource_group_level(resource_name, resource_group_name)
 
-    return client.get_subscription_level_alert(resource_name)
+    return client.get_subscription_level(resource_name)
 
 
 def update_security_alert(client, location, resource_name, status, resource_group_name=None):
 
-    client.config.asc_location = location
+    client._config.asc_location = location  # pylint: disable=protected-access
 
     if resource_group_name:
         if status == "Dismiss":
-            client.update_resource_group_level_alert_state_to_dismiss(resource_name, resource_group_name)
+            client.update_resource_group_level_state_to_dismiss(resource_name, resource_group_name)
         if status == "Activate":
-            client.update_resource_group_level_alert_state_to_reactivate(resource_name, resource_group_name)
+            client.update_resource_group_level_state_to_activate(resource_name, resource_group_name)
         if status == "Resolve":
             client.update_resource_group_level_state_to_resolve(resource_name, resource_group_name)
     else:
         if status == "Dismiss":
-            client.update_subscription_level_alert_state_to_dismiss(resource_name)
+            client.update_subscription_level_state_to_dismiss(resource_name)
         if status == "Activate":
-            client.update_subscription_level_alert_state_to_reactivate(resource_name)
+            client.update_subscription_level_state_to_activate(resource_name)
         if status == "Resolve":
             client.update_subscription_level_state_to_resolve(resource_name)
 
@@ -101,9 +125,20 @@ def list_security_settings(client):
     return client.list()
 
 
-def get_security_setting(client, resource_name):
+def get_security_setting(client, setting_name):
 
-    return client.get(resource_name)
+    return client.get(setting_name)
+
+
+def update_security_setting(client, setting_name, enabled):
+
+    if setting_name == Enum69.SENTINEL:
+        setting = AlertSyncSettings()
+    else:
+        setting = DataExportSettings()
+
+    setting.enabled = enabled
+    return client.update(setting_name, setting)
 
 
 # --------------------------------------------------------------------------------------------
@@ -161,13 +196,13 @@ def get_security_auto_provisioning_setting(client, resource_name):
 
 def update_security_auto_provisioning_setting(client, auto_provision, resource_name):
 
-    new_auto_provision = AutoProvision(auto_provision)
+    new_auto_provision = AutoProvisioningSetting(auto_provision=auto_provision)
     return client.create(resource_name, new_auto_provision)
 
 
 def turn_off_security_auto_provisioning_setting(client, resource_name):
 
-    new_auto_provision = AutoProvision('Off')
+    new_auto_provision = AutoProvisioningSetting(auto_provision='Off')
     return client.create(resource_name, new_auto_provision)
 
 
@@ -178,7 +213,7 @@ def turn_off_security_auto_provisioning_setting(client, resource_name):
 def list_security_discovered_security_solutions(client):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.discovered_security_solutions.list()
 
@@ -186,7 +221,7 @@ def list_security_discovered_security_solutions(client):
 def get_security_discovered_security_solution(client, resource_name, resource_group_name):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.discovered_security_solutions.get(resource_group_name, resource_name)
 
@@ -198,7 +233,7 @@ def get_security_discovered_security_solution(client, resource_name, resource_gr
 def list_security_external_security_solutions(client):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.external_security_solutions.list()
 
@@ -206,7 +241,7 @@ def list_security_external_security_solutions(client):
 def get_security_external_security_solution(client, resource_name, resource_group_name):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.external_security_solutions.get(resource_group_name, resource_name)
 
@@ -218,7 +253,7 @@ def get_security_external_security_solution(client, resource_name, resource_grou
 def list_security_jit_network_access_policies(client, resource_group_name=None, location=None):
 
     if location:
-        client.config.asc_location = location
+        client._config.asc_location = location  # pylint: disable=protected-access
 
         if resource_group_name:
             return client.list_by_resource_group_and_region(resource_group_name)
@@ -233,7 +268,7 @@ def list_security_jit_network_access_policies(client, resource_group_name=None,
 
 def get_security_jit_network_access_policy(client, location, resource_name, resource_group_name):
 
-    client.config.asc_location = location
+    client._config.asc_location = location  # pylint: disable=protected-access
 
     return client.get(resource_group_name, resource_name)
 
@@ -249,7 +284,7 @@ def list_security_locations(client):
 
 def get_security_location(client, resource_name):
 
-    client.config.asc_location = resource_name
+    client._config.asc_location = resource_name  # pylint: disable=protected-access
 
     return client.get()
 
@@ -270,7 +305,7 @@ def get_security_pricing(client, resource_name):
 
 def create_security_pricing(client, resource_name, tier):
 
-    return client.update(resource_name, tier)
+    return client.update(resource_name, Pricing(pricing_tier=tier))
 
 # --------------------------------------------------------------------------------------------
 # Security Topology
@@ -280,7 +315,7 @@ def create_security_pricing(client, resource_name, tier):
 def list_security_topology(client):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.topology.list()
 
@@ -288,7 +323,7 @@ def list_security_topology(client):
 def get_security_topology(client, resource_name, resource_group_name):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.topology.get(resource_group_name, resource_name)
 
@@ -308,10 +343,10 @@ def get_security_workspace_setting(client, resource_name):
     return client.get(resource_name)
 
 
-def create_security_workspace_setting(client, resource_name, target_workspace):
+def create_security_workspace_setting(cmd, client, resource_name, target_workspace):
 
-    scope = '/subscriptions/' + client.config.subscription_id
-    return client.create(resource_name, target_workspace, scope)
+    scope = '/subscriptions/' + get_subscription_id(cmd.cli_ctx)
+    return client.create(resource_name, WorkspaceSetting(workspace_id=target_workspace, scope=scope))
 
 
 def delete_security_workspace_setting(client, resource_name):
@@ -323,47 +358,133 @@ def delete_security_workspace_setting(client, resource_name):
 # Security ATP
 # --------------------------------------------------------------------------------------------
 
-def get_atp_setting(client, resource_group_name, storage_account_name):
+def get_atp_setting(cmd, client, resource_group_name, storage_account_name):
 
-    return client.get(_construct_resource_id(client, resource_group_name, storage_account_name))
+    return client.get(_construct_resource_id(cmd, resource_group_name, storage_account_name))
 
 
-def update_atp_setting(client, resource_group_name, storage_account_name, is_enabled):
+def update_atp_setting(cmd, client, resource_group_name, storage_account_name, is_enabled):
 
-    return client.create(_construct_resource_id(client, resource_group_name, storage_account_name),
-                         is_enabled=is_enabled)
+    return client.create(_construct_resource_id(cmd, resource_group_name, storage_account_name),
+                         AdvancedThreatProtectionSetting(is_enabled=is_enabled))
 
 
-def _construct_resource_id(client, resource_group_name, storage_account_name):
+def _construct_resource_id(cmd, resource_group_name, storage_account_name):
 
     return resource_id(
-        subscription=client.config.subscription_id,
+        subscription=get_subscription_id(cmd.cli_ctx),
         resource_group=resource_group_name,
         namespace='Microsoft.Storage',
         type='storageAccounts',
         name=storage_account_name)
 
 
+# --------------------------------------------------------------------------------------------
+# Sql Vulnerability Assessment
+# --------------------------------------------------------------------------------------------
+
+
+# pylint: disable=line-too-long
+def get_va_sql_scan(client, vm_resource_id, workspace_id, server_name, database_name, scan_id, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.get(scan_id, workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def list_va_sql_scans(client, vm_resource_id, workspace_id, server_name, database_name, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.list(workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def get_va_sql_result(client, vm_resource_id, workspace_id, server_name, database_name, scan_id, rule_id, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.get(scan_id, rule_id, workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def list_va_sql_results(client, vm_resource_id, workspace_id, server_name, database_name, scan_id, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.list(scan_id, workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def get_va_sql_baseline(client, vm_resource_id, workspace_id, server_name, database_name, rule_id, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.get(rule_id, workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def list_va_sql_baseline(client, vm_resource_id, workspace_id, server_name, database_name, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.list(workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def delete_va_sql_baseline(client, vm_resource_id, workspace_id, server_name, database_name, rule_id, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    return client.delete(rule_id, workspace_id, va_sql_resource_id)
+
+
+# pylint: disable=line-too-long
+def update_va_sql_baseline(client, vm_resource_id, workspace_id, server_name, database_name, rule_id, baseline=None, baseline_latest=False, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    if baseline_latest is True and baseline is None:
+        return client.create_or_update(rule_id, workspace_id, va_sql_resource_id, RuleResultsInput(latest_scan=True))
+    if baseline_latest is False and baseline is not None:
+        return client.create_or_update(rule_id, workspace_id, va_sql_resource_id, RuleResultsInput(results=baseline))
+    raise MutuallyExclusiveArgumentError("Baseline can be set upon either provided baseline or latest results")
+
+
+# pylint: disable=line-too-long
+def set_va_sql_baseline(client, vm_resource_id, workspace_id, server_name, database_name, baseline=None, baseline_latest=False, vm_name=None, agent_id=None, vm_uuid=None):
+
+    va_sql_resource_id = _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid)
+    if baseline_latest is True and baseline is None:
+        return client.add(workspace_id, va_sql_resource_id, RulesResultsInput(latest_scan=True))
+    if baseline_latest is False and baseline is not None:
+        return client.add(workspace_id, va_sql_resource_id, RulesResultsInput(results=baseline))
+    raise MutuallyExclusiveArgumentError("Baseline can be set upon either provided baseline or latest results")
+
+
+def _get_va_sql_resource_id(vm_resource_id, server_name, database_name, vm_name, agent_id, vm_uuid):
+
+    if vm_name is None and agent_id is None and vm_uuid is None:
+        return f'{vm_resource_id}/sqlServers/{server_name}/databases/{database_name}'
+    if vm_name is not None and agent_id is not None and vm_uuid is not None:
+        vm_identifier = f'{vm_name}_{agent_id}_{vm_uuid}'
+        return f'{vm_resource_id}/onPremiseMachines/{vm_identifier}/sqlServers/{server_name}/databases/{database_name}'
+    raise MutuallyExclusiveArgumentError('Please specify all of (--vm-name, --agent-id, --vm-uuid) for On-Premise resources, or none, other resource types')
+
+
 # --------------------------------------------------------------------------------------------
 # Security Assessments
 # --------------------------------------------------------------------------------------------
 
 
-def list_security_assessments(client):
+def list_security_assessments(cmd, client):
 
-    return client.list(scope='/subscriptions/' + client.config.subscription_id)
+    return client.list(scope='/subscriptions/' + get_subscription_id(cmd.cli_ctx))
 
 
-def get_security_assessment(client, resource_name, assessed_resource_id=None):
+def get_security_assessment(cmd, client, resource_name, assessed_resource_id=None):
 
     if assessed_resource_id is None:
-        assessed_resource_id = '/subscriptions/' + client.config.subscription_id
-
+        assessed_resource_id = '/subscriptions/' + get_subscription_id(cmd.cli_ctx)
     return client.get(assessed_resource_id,
                       assessment_name=resource_name)
 
 
-def create_security_assessment(client,
+def create_security_assessment(cmd,
+                               client,
                                resource_name,
                                status_code,
                                status_cause=None,
@@ -372,7 +493,7 @@ def create_security_assessment(client,
                                assessed_resource_id=None):
 
     if assessed_resource_id is None:
-        assessed_resource_id = resource_id(subscription=client.config.subscription_id)
+        assessed_resource_id = resource_id(subscription=get_subscription_id(cmd.cli_ctx))
 
     resource_details = AzureResourceDetails(source="Azure")
 
@@ -390,10 +511,10 @@ def create_security_assessment(client,
                                    assessment=new_assessment)
 
 
-def delete_security_assessment(client, resource_name, assessed_resource_id=None):
+def delete_security_assessment(cmd, client, resource_name, assessed_resource_id=None):
 
     if assessed_resource_id is None:
-        assessed_resource_id = resource_id(subscription=client.config.subscription_id)
+        assessed_resource_id = resource_id(subscription=get_subscription_id(cmd.cli_ctx))
 
     return client.delete(assessment_name=resource_name,
                          resource_id=assessed_resource_id)
@@ -443,19 +564,19 @@ def delete_security_assessment_metadata(client, resource_name):
 # --------------------------------------------------------------------------------------------
 
 
-def list_security_sub_assessments(client, assessment_name=None, assessed_resource_id=None):
+def list_security_sub_assessments(cmd, client, assessment_name=None, assessed_resource_id=None):
 
     if assessed_resource_id is None:
-        assessed_resource_id = '/subscriptions/' + client.config.subscription_id
+        assessed_resource_id = '/subscriptions/' + get_subscription_id(cmd.cli_ctx)
         return client.list_all(scope=assessed_resource_id)
 
     return client.list(scope=assessed_resource_id, assessment_name=assessment_name)
 
 
-def get_security_sub_assessment(client, resource_name, assessment_name, assessed_resource_id=None):
+def get_security_sub_assessment(cmd, client, resource_name, assessment_name, assessed_resource_id=None):
 
     if assessed_resource_id is None:
-        assessed_resource_id = '/subscriptions/' + client.config.subscription_id
+        assessed_resource_id = '/subscriptions/' + get_subscription_id(cmd.cli_ctx)
 
     return client.get(sub_assessment_name=resource_name,
                       assessment_name=assessment_name,
@@ -516,7 +637,7 @@ def list_security_adaptive_network_hardenings(client,
 def list_security_allowed_connections(client):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.allowed_connections.list()
 
@@ -524,7 +645,7 @@ def list_security_allowed_connections(client):
 def get_security_allowed_connections(client, resource_name, resource_group_name):
 
     for loc in client.locations.list():
-        client.config.asc_location = loc.name
+        client._config.asc_location = loc.name  # pylint: disable=protected-access
 
     return client.allowed_connections.get(resource_group_name, resource_name)
 
@@ -709,3 +830,154 @@ def list_by_score(client, resource_name):
 def list_secure_score_control_definitions(client):
 
     return client.list_by_subscription()
+
+# --------------------------------------------------------------------------------------------
+# Security Automations
+# --------------------------------------------------------------------------------------------
+
+
+def list_security_automations(client, resource_group_name=None):
+
+    if resource_group_name:
+        return client.list_by_resource_group(resource_group_name)
+
+    return client.list()
+
+
+def get_security_automation(client, resource_group_name, resource_name):
+
+    return client.get(resource_group_name, resource_name)
+
+
+def delete_security_automation(client, resource_group_name, resource_name):
+
+    return client.delete(resource_group_name, resource_name)
+
+
+def create_or_update_security_automation(client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
+
+    if location is None:
+        resourceGroup = run_cli_cmd('az group show --name {}'.format(resource_group_name))
+        location = resourceGroup['location']
+    automation = create_security_automation_object(location, scopes, sources, actions, etag, tags, description, isEnabled)
+    return client.create_or_update(resource_group_name, resource_name, automation)
+
+
+def validate_security_automation(client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
+
+    if location is None:
+        resourceGroup = run_cli_cmd('az group show --name {}'.format(resource_group_name))
+        location = resourceGroup['location']
+    automation = create_security_automation_object(location, scopes, sources, actions, etag, tags, description, isEnabled)
+    return client.validate(resource_group_name, resource_name, automation)
+
+
+def create_security_automation_scope(description, scope_path):
+
+    return AutomationScope(description=description, scope_path=scope_path)
+
+
+def create_security_automation_rule(expected_value, operator, property_j_path, property_type):
+
+    return AutomationTriggeringRule(property_j_path=property_j_path, property_type=property_type, expected_value=expected_value, operator=operator)
+
+
+def create_security_automation_rule_set(rules=None):
+
+    return AutomationRuleSet(rules=rules)
+
+
+def create_security_automation_source(event_source, rule_sets=None):
+
+    return AutomationSource(event_source=event_source, rule_sets=rule_sets)
+
+
+def create_security_automation_action_logic_app(logic_app_resource_id, uri):
+
+    return AutomationActionLogicApp(logic_app_resource_id=logic_app_resource_id, uri=uri)
+
+
+def create_security_automation_action_event_hub(event_hub_resource_id, connection_string, sas_policy_name=None):
+
+    automationActionEventHub = AutomationActionEventHub(event_hub_resource_id=event_hub_resource_id, connection_string=connection_string)
+    automationActionEventHub.sas_policy_name = sas_policy_name
+    return automationActionEventHub
+
+
+def create_security_automation_action_workspace(workspace_resource_id):
+
+    return AutomationActionWorkspace(workspace_resource_id=workspace_resource_id)
+
+
+# Security Automations Utils
+
+
+def create_security_automation_object(location, scopes, sources, actions, etag=None, tags=None, description=None, isEnabled=None):
+
+    scopes = sanitize_json_as_string(scopes)
+    sources = sanitize_json_as_string(sources)
+    actions = sanitize_json_as_string(actions)
+
+    scopes = json.loads(scopes)
+    scopesAsObjectList = []
+    for scope in scopes:
+        scopeAsObject = AutomationScope(description=scope['description'], scope_path=scope['scopePath'])
+        scopesAsObjectList.append(scopeAsObject)
+
+    sources = json.loads(sources)
+    sourcesAsObjectList = []
+    for source in sources:
+        sourceAsObject = AutomationSource(event_source=source['eventSource'], rule_sets=get_security_automation_ruleSets_object(source['ruleSets']))
+        sourcesAsObjectList.append(sourceAsObject)
+
+    actions = json.loads(actions)
+    actionsAsObjectList = []
+    for action in actions:
+        if action['actionType'] == 'LogicApp':
+            actionAsObject = AutomationActionLogicApp(logic_app_resource_id=action['logicAppResourceId'], uri=action['ruleSets'])
+        elif action['actionType'] == 'EventHub':
+            actionAsObject = AutomationActionEventHub(event_hub_resource_id=action['eventHubResourceId'], connection_string=action['connectionString'])
+        elif action['actionType'] == 'Workspace':
+            actionAsObject = AutomationActionWorkspace(workspace_resource_id=action['workspaceResourceId'])
+
+        actionsAsObjectList.append(actionAsObject)
+
+    if tags is not None:
+        tags = json.loads(tags)
+
+    return Automation(location=location,
+                      scopes=scopesAsObjectList,
+                      sources=sourcesAsObjectList,
+                      actions=actionsAsObjectList,
+                      tags=tags,
+                      etag=etag,
+                      description=description,
+                      isEnabled=isEnabled)
+
+
+def get_security_automation_ruleSets_object(ruleSets):
+    if ruleSets is None:
+        return
+    ruleSetsAsObjectList = []
+    for ruleSet in ruleSets:
+        ruleSetAsObject = AutomationRuleSet(rules=get_security_automation_rules_object(ruleSet['rules']))
+        ruleSetsAsObjectList.append(ruleSetAsObject)
+    return ruleSetsAsObjectList
+
+
+def get_security_automation_rules_object(rules):
+    if rules is None:
+        return
+    ruleAsObjectList = []
+    for rule in rules:
+        ruleAsObject = AutomationTriggeringRule(property_j_path=rule['propertyJPath'], property_type=rule['propertyType'], expected_value=rule['expectedValue'], operator=rule['operator'])
+        ruleAsObjectList.append(ruleAsObject)
+    return ruleAsObjectList
+
+
+def sanitize_json_as_string(value: string):
+    valueLength = len(value)
+    if((value[0] == '\'' and value[valueLength - 1] == '\'') or (value[0] == '\"' and value[valueLength - 1] == '\"')):
+        value = value[1:]
+        value = value[:-1]
+    return value
