@@ -130,7 +130,7 @@ class WebAppAddonScenarioTest(ScenarioTest):
 
         # validate the created postgres
         vault_name = target_id.split('/')[-1]
-        self.cmd('keyvault show --connection {}'.format(vault_name))
+        self.cmd('keyvault show --name {}'.format(vault_name))
         self.cmd('webapp connection show --id {}'.format(connection_id))
 
 
@@ -159,5 +159,5 @@ class WebAppAddonScenarioTest(ScenarioTest):
 
         # validate the created postgres
         account_name = target_id.split('/')[-3]
-        self.cmd('storage account show --connection {}'.format(account_name))
+        self.cmd('storage account show --name {}'.format(account_name))
         self.cmd('webapp connection show --id {}'.format(connection_id))
