@@ -5,7 +5,6 @@
 
 from azure.cli.command_modules.storage._client_factory import (cf_sa, cf_blob_container_mgmt, blob_data_service_factory,
                                                                page_blob_service_factory, file_data_service_factory,
-                                                               queue_data_service_factory,
                                                                multi_service_properties_factory,
                                                                cf_mgmt_policy,
                                                                cf_blob_data_gen_update, cf_sa_for_keys,
@@ -17,7 +16,7 @@ from azure.cli.command_modules.storage._client_factory import (cf_sa, cf_blob_co
                                                                cf_blob_client, cf_blob_lease_client,
                                                                cf_or_policy, cf_container_client,
                                                                cf_queue_service, cf_table_service, cf_table_client,
-                                                               cf_sa_blob_inventory, cf_blob_service)
+                                                               cf_sa_blob_inventory, cf_blob_service, cf_queue_client)
 
 from azure.cli.core.commands import CliCommandType
 from azure.cli.core.commands.arm import show_exception_handler
@@ -679,62 +678,78 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
         g.storage_command('list', 'list_cors',
                           transform=transform_cors_list_output)
 
-    queue_sdk = CliCommandType(operations_tmpl='azure.multiapi.storage.queue.queueservice#QueueService.{}',
-                               client_factory=queue_data_service_factory,
-                               resource_type=ResourceType.DATA_STORAGE)
+    queue_client_sdk = CliCommandType(
+        operations_tmpl='azure.multiapi.storagev2.queue._queue_client#QueueClient.{}',
+        client_factory=cf_queue_client, resource_type=ResourceType.DATA_STORAGE_QUEUE)
 
-    with self.command_group('storage queue', queue_sdk,
-                            custom_command_type=get_custom_sdk('acl', queue_data_service_factory)) as g:
+    with self.command_group('storage queue', command_type=queue_client_sdk, is_preview=True,
+                            custom_command_type=get_custom_sdk('queue', cf_queue_client,
+                                                               ResourceType.DATA_STORAGE_QUEUE),
+                            resource_type=ResourceType.DATA_STORAGE_QUEUE, min_api='2018-03-28') as g:
         from ._format import transform_boolean_for_table
         from ._transformers import create_boolean_result_output_transformer
 
-        g.storage_command_oauth('create', 'create_queue', transform=create_boolean_result_output_transformer('created'),
-                                table_transformer=transform_boolean_for_table)
-        g.storage_command_oauth('delete', 'delete_queue', transform=create_boolean_result_output_transformer('deleted'),
-                                table_transformer=transform_boolean_for_table)
-        g.storage_command_oauth(
-            'generate-sas', 'generate_queue_shared_access_signature')
-        g.storage_command_oauth(
-            'stats', 'get_queue_service_stats', min_api='2016-05-31')
-        g.storage_command_oauth(
-            'exists', 'exists', transform=create_boolean_result_output_transformer('exists'))
+        g.storage_custom_command_oauth('create', 'create_queue',
+                                       transform=create_boolean_result_output_transformer('created'),
+                                       table_transformer=transform_boolean_for_table)
+        g.storage_custom_command_oauth('delete', 'delete_queue',
+                                       transform=create_boolean_result_output_transformer('deleted'),
+                                       table_transformer=transform_boolean_for_table)
+        g.storage_custom_command(
+            'generate-sas', 'generate_queue_sas')
+        g.storage_custom_command_oauth('exists', 'queue_exists',
+                                       transform=create_boolean_result_output_transformer('exists'))
 
         g.storage_command_oauth(
-            'metadata show', 'get_queue_metadata', exception_handler=show_exception_handler)
-        g.storage_command_oauth('metadata update', 'set_queue_metadata')
+            'metadata show', 'get_queue_properties',
+            exception_handler=show_exception_handler, transform=lambda x: getattr(x, 'metadata', x))
+        g.storage_command_oauth('metadata update', 'set_queue_metadata',
+                                transform=create_boolean_result_output_transformer('updated'))
 
-        g.storage_custom_command_oauth('policy create', 'create_acl_policy')
-        g.storage_custom_command_oauth('policy delete', 'delete_acl_policy')
-        g.storage_custom_command_oauth(
-            'policy show', 'get_acl_policy', exception_handler=show_exception_handler)
-        g.storage_custom_command_oauth(
-            'policy list', 'list_acl_policies', table_transformer=transform_acl_list_output)
-        g.storage_custom_command_oauth('policy update', 'set_acl_policy')
+    with self.command_group('storage queue policy', command_type=queue_client_sdk, is_preview=True,
+                            custom_command_type=get_custom_sdk('access_policy', cf_queue_client,
+                                                               ResourceType.DATA_STORAGE_QUEUE),
+                            resource_type=ResourceType.DATA_STORAGE_QUEUE, min_api='2018-03-28') as g:
+        from ._transformers import (transform_acl_list_output, transform_queue_policy_output,
+                                    transform_queue_policy_json_output)
+        g.storage_custom_command_oauth('create', 'create_acl_policy')
+        g.storage_custom_command_oauth('delete', 'delete_acl_policy')
+        g.storage_custom_command_oauth('show', 'get_acl_policy',
+                                       transform=transform_queue_policy_output,
+                                       exception_handler=show_exception_handler)
+        g.storage_custom_command_oauth('list', 'list_acl_policies',
+                                       transform=transform_queue_policy_json_output,
+                                       table_transformer=transform_acl_list_output)
+        g.storage_custom_command_oauth('update', 'set_acl_policy')
 
-    with self.command_group('storage message', queue_sdk) as g:
-        from ._transformers import create_boolean_result_output_transformer
+    with self.command_group('storage message', command_type=queue_client_sdk, is_preview=True,
+                            custom_command_type=get_custom_sdk('queue', cf_queue_client,
+                                                               ResourceType.DATA_STORAGE_QUEUE),
+                            resource_type=ResourceType.DATA_STORAGE_QUEUE, min_api='2018-03-28') as g:
+        from ._transformers import (transform_message_list_output, transform_message_output)
         from ._format import transform_message_show
 
-        g.storage_command_oauth('put', 'put_message')
-        g.storage_command_oauth('get', 'get_messages',
-                                table_transformer=transform_message_show)
-        g.storage_command_oauth('peek', 'peek_messages',
+        g.storage_command_oauth('put', 'send_message', transform=transform_message_output)
+        g.storage_custom_command_oauth('get', 'receive_messages', transform=transform_message_list_output,
+                                       table_transformer=transform_message_show)
+        g.storage_command_oauth('peek', 'peek_messages', transform=transform_message_list_output,
                                 table_transformer=transform_message_show)
         g.storage_command_oauth('delete', 'delete_message',
-                                transform=create_boolean_result_output_transformer(
-                                    'deleted'),
+                                transform=create_boolean_result_output_transformer('deleted'),
                                 table_transformer=transform_boolean_for_table)
         g.storage_command_oauth('clear', 'clear_messages')
-        g.storage_command_oauth('update', 'update_message')
+        g.storage_command_oauth('update', 'update_message', transform=transform_message_output)
 
     queue_service_sdk = CliCommandType(
         operations_tmpl='azure.multiapi.storagev2.queue._queue_service_client#QueueServiceClient.{}',
         client_factory=cf_queue_service, resource_type=ResourceType.DATA_STORAGE_QUEUE)
 
-    with self.command_group('storage queue', queue_service_sdk,
-                            resource_type=ResourceType.DATA_STORAGE_QUEUE, min_api='2018-03-28',
-                            custom_command_type=get_custom_sdk('queue', client_factory=cf_queue_service,
-                                                               resource_type=ResourceType.DATA_STORAGE_QUEUE)) as g:
+    with self.command_group('storage queue', command_type=queue_service_sdk, is_preview=True,
+                            custom_command_type=get_custom_sdk('queue', cf_queue_service,
+                                                               ResourceType.DATA_STORAGE_QUEUE),
+                            resource_type=ResourceType.DATA_STORAGE_QUEUE, min_api='2018-03-28') as g:
+        from ._transformers import transform_queue_stats_output
+        g.storage_command_oauth('stats', 'get_service_stats', transform=transform_queue_stats_output)
         g.storage_custom_command_oauth('list', 'list_queues', transform=transform_storage_list_output)
 
     table_service_sdk = CliCommandType(operations_tmpl='azure.data.tables._table_service_client#TableServiceClient.{}',
@@ -831,6 +846,14 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
                                 transform=transform_metadata)
         g.storage_custom_command_oauth('generate-sas', 'generate_sas_fs_uri', is_preview=True,
                                        custom_command_type=get_custom_sdk('filesystem', client_factory=cf_adls_service))
+        g.storage_custom_command_oauth('list-deleted-path', 'list_deleted_path', min_api='2020-06-12')
+        g.storage_command_oauth('undelete-path', '_undelete_path', min_api='2020-06-12')
+
+    with self.command_group('storage fs service-properties', command_type=adls_service_sdk,
+                            custom_command_type=get_custom_sdk('filesystem', cf_adls_service),
+                            resource_type=ResourceType.DATA_STORAGE_FILEDATALAKE, min_api='2020-06-12') as g:
+        g.storage_command_oauth('show', 'get_service_properties', exception_handler=show_exception_handler)
+        g.storage_custom_command_oauth('update', 'set_service_properties')
 
     with self.command_group('storage fs directory', adls_directory_sdk,
                             custom_command_type=get_custom_sdk('fs_directory', cf_adls_directory),
