@@ -20,14 +20,12 @@ class StorageBatchOperationScenarios(StorageScenarioMixin, LiveScenarioTest):
         # upload test files to storage account
         self.storage_cmd('storage blob upload-batch -s "{}" -d {} --max-connections 3', storage_account_info,
                          test_dir, src_container)
-        from azure.cli.core.azclierror import AzureResponseError
-        with self.assertRaises(AzureResponseError):
-            self.storage_cmd('storage blob upload-batch -s "{}" -d {} --max-connections 3', storage_account_info,
-                                 test_dir, src_container)
+
+        # test upload-batch with & without --overwrite
+        self.storage_cmd('storage blob upload-batch -s "{}" -d {} --max-connections 3', storage_account_info,
+                         test_dir, src_container).assert_with_checks(JMESPathCheck('length(@)', 0))
         self.storage_cmd('storage blob upload-batch -s "{}" -d {} --max-connections 3 --overwrite', storage_account_info,
-                         test_dir, src_container)
-        self.storage_cmd('storage blob list -c {}', storage_account_info, src_container).assert_with_checks(
-            JMESPathCheck('length(@)', 41))
+                         test_dir, src_container).assert_with_checks(JMESPathCheck('length(@)', 41))
 
         # download recursively without pattern
         local_folder = self.create_temp_dir()
@@ -57,6 +55,12 @@ class StorageBatchOperationScenarios(StorageScenarioMixin, LiveScenarioTest):
                          local_folder, '*/file_0')
         self.assertEqual(4, sum(len(f) for r, d, f in os.walk(local_folder)))
 
+        # download blob without wild cards
+        local_folder = self.create_temp_dir()
+        self.storage_cmd('storage blob download-batch -s {} -d "{}" --pattern {}', storage_account_info, src_container,
+                         local_folder, 'apple/file_0')
+        self.assertEqual(1, sum(len(f) for r, d, f in os.walk(local_folder)))
+
         # upload blobs with names that start with path separator
         local_file = self.create_temp_file(1)
         src_container = self.create_container(storage_account_info)
