@@ -73,26 +73,31 @@ class StorageSASScenario(StorageScenarioMixin, LiveScenarioTest):
         container = self.create_container(account_info)
         local_file = self.create_temp_file(128, full_random=False)
         blob_name = self.create_random_name('blob', 16)
+        scope_name = self.create_random_name('scope', 16)
 
         self.kwargs.update({
             'expiry': expiry,
             'account': storage_account,
             'container': container,
             'local_file': local_file,
-            'blob': blob_name
+            'blob': blob_name,
+            'scope_name': scope_name
         })
 
         # account key
         # test sas-token for a container
-        sas = self.storage_cmd('storage container generate-sas -n {} --https-only --permissions dlrw --expiry {} -otsv',
-                               account_info, container, expiry).output.strip()
+        self.cmd('storage account encryption-scope create -n {scope_name} --account-name {account}')
+        sas = self.storage_cmd('storage container generate-sas -n {} --https-only --permissions dlrw --expiry {} '
+                               '--encryption-scope {} -otsv',
+                               account_info, container, expiry, scope_name).output.strip()
         self.kwargs['container_sas'] = sas
         self.cmd('storage blob upload -c {container} -f "{local_file}" -n {blob} '
                  '--account-name {account} --sas-token "{container_sas}"')
 
         # test sas-token for a file
         sas = self.storage_cmd('storage blob generate-sas -c {} -n {} --https-only --permissions acdrw --expiry {} '
-                               '-otsv', account_info, container, blob_name, expiry).output.strip()
+                               '--encryption-scope {}'
+                               '-otsv', account_info, container, blob_name, expiry, scope_name).output.strip()
         self.kwargs['blob_sas'] = sas
         self.cmd('storage blob show -c {container} -n {blob} --account-name {account} --sas-token {blob_sas}') \
             .assert_with_checks(JMESPathCheck('name', blob_name))
@@ -123,8 +128,8 @@ class StorageSASScenario(StorageScenarioMixin, LiveScenarioTest):
         self.cmd('storage blob show -c {container} -n {blob} --account-name {account} --sas-token {blob_sas}') \
             .assert_with_checks(JMESPathCheck('name', blob_name))
 
-    @ResourceGroupPreparer()
-    @StorageAccountPreparer()
+    @ResourceGroupPreparer(name_prefix='clitest')
+    @StorageAccountPreparer(name_prefix='queuesas', kind='StorageV2', location='eastus2', sku='Standard_RAGRS')
     def test_storage_queue_sas_scenario(self, resource_group, storage_account):
         from datetime import datetime, timedelta
         expiry = (datetime.utcnow() + timedelta(hours=1)).strftime('%Y-%m-%dT%H:%MZ')
@@ -140,6 +145,14 @@ class StorageSASScenario(StorageScenarioMixin, LiveScenarioTest):
 
         self.cmd('storage queue exists -n {} --account-name {} --sas-token {}'.format(queue, storage_account, sas),
                  checks=JMESPathCheck('exists', True))
+        self.storage_cmd('storage queue policy create -n testqp -q {} --permissions r --expiry {}',
+                         account_info, queue, expiry)
+
+        sas2 = self.storage_cmd('storage queue generate-sas -n {} --policy-name testqp', account_info, queue).output
+        self.assertIn('sig', sas2, 'The sig segment is not in the sas {}'.format(sas2))
+
+        self.cmd('storage queue exists -n {} --account-name {} --sas-token {}'.format(queue, storage_account, sas2),
+                 checks=JMESPathCheck('exists', True))
 
     @ResourceGroupPreparer()
     @StorageAccountPreparer()
@@ -147,9 +160,18 @@ class StorageSASScenario(StorageScenarioMixin, LiveScenarioTest):
         from datetime import datetime, timedelta
         expiry = (datetime.utcnow() + timedelta(hours=1)).strftime('%Y-%m-%dT%H:%MZ')
         connection_str = self.cmd('storage account show-connection-string -n {} -otsv'.format(storage_account)).output
+        scope_name = self.create_random_name('scope', 16)
+
+        self.kwargs.update({
+            'account': storage_account,
+            'scope_name': scope_name
+        })
+        self.cmd('storage account encryption-scope create -n {scope_name} --account-name {account}')
         sas = self.cmd('storage account generate-sas --resource-types co --services b '
-                       '--expiry {} --permissions r --https-only --connection-string {}'
-                       .format(expiry, connection_str)).output.strip()
+                       '--expiry {} --permissions r --https-only --connection-string {} '
+                       '--encryption-scope {}'
+                       .format(expiry, connection_str, scope_name)).output.strip()
+
         self.assertIn('sig=', sas, 'SAS token {} does not contain sig segment'.format(sas))
         self.assertIn('se=', sas, 'SAS token {} does not contain se segment'.format(sas))
 
