@@ -28,8 +28,11 @@ def collect_blob_objects(blob_service, container, pattern=None):
         raise ValueError('missing parameter container')
 
     if not _pattern_has_wildcards(pattern):
-        if blob_service.exists(container, pattern):
-            yield pattern, blob_service.get_blob_properties(container, pattern)
+        from azure.core.exceptions import ResourceNotFoundError
+        try:
+            yield pattern, blob_service.get_blob_client(container, pattern).get_blob_properties()
+        except ResourceNotFoundError:
+            return
     else:
         if hasattr(blob_service, 'list_blobs'):
             blobs = blob_service.list_blobs(container)
