@@ -30,6 +30,8 @@ def load_command_table(self, _):
     from ._client_factory import cf_synapse_client_integrationruntimeconnectioninfos_factory
     from ._client_factory import cf_synapse_client_integrationruntimestatus_factory
     from ._client_factory import cf_kusto_pool
+    from ._client_factory import cf_kusto_script
+    from ._client_factory import cf_kusto_scripts
 
     def get_custom_sdk(custom_module, client_factory):
         return CliCommandType(
@@ -199,6 +201,12 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.synapse.operations._kusto_pools_operations#KustoPoolsOperations.{}',
         client_factory=cf_kusto_pool,
     )
+
+    synapse_kusto_script_sdk = CliCommandType(
+        operations_tmpl='azure.synapse.artifacts.operations#KqlScriptOperations.{}',
+        client_factory=cf_kusto_script,
+    )
+
     # Management Plane Commands --Workspace
     with self.command_group('synapse workspace', command_type=synapse_workspace_sdk,
                             custom_command_type=get_custom_sdk('workspace', cf_synapse_client_workspace_factory),
@@ -558,3 +566,14 @@ def load_command_table(self, _):
         g.custom_command('add-language-extension', 'synapse_kusto_pool_add_language_extension', supports_no_wait=True)
         g.custom_command('detach-follower-database', 'synapse_kusto_pool_detach_follower_database', supports_no_wait=True)
         g.custom_command('remove-language-extension', 'synapse_kusto_pool_remove_language_extension', supports_no_wait=True)
+
+    with self.command_group('synapse kql-script', command_type=synapse_kusto_script_sdk,
+                            custom_command_type=get_custom_sdk('kustopool', cf_kusto_script),
+                            client_factory=cf_kusto_script) as g:
+        g.custom_show_command('show', 'synapse_kusto_script_show')
+        g.custom_command('create', 'synapse_kusto_script_create', supports_no_wait=True)
+        g.custom_command('import', 'synapse_kusto_script_create', supports_no_wait=True)
+        g.custom_command('delete', 'synapse_kusto_script_delete', supports_no_wait=True, confirmation=True)
+        g.custom_command('list', 'synapse_kusto_script_list', client_factory=cf_kusto_scripts)
+        g.custom_command('export', 'synapse_kusto_script_export')
+        g.custom_wait_command('wait', 'synapse_kusto_script_show')
