@@ -35,12 +35,10 @@ def sqlpool_blob_auditing_policy_update(
         event_hub_target_state=None,
         event_hub_authorization_rule_id=None,
         event_hub=None,
-        is_azure_monitor_target_enabled=None,
-        blob_auditing_policy_name=None):
+        is_azure_monitor_target_enabled=None):
     """
     Updates a sql pool blob auditing policy. Custom update function to apply parameters to instance.
     """
-
     _audit_policy_update(
         cmd=cmd,
         instance=instance,
@@ -71,6 +69,7 @@ def sqlserver_blob_auditing_policy_update(
         instance,
         workspace_name,
         resource_group_name,
+        blob_auditing_policy_name='default',
         state=None,
         blob_storage_target_state=None,
         storage_account=None,
@@ -86,8 +85,7 @@ def sqlserver_blob_auditing_policy_update(
         storage_account_subscription_id=None,
         is_storage_secondary_key_in_use=None,
         is_azure_monitor_target_enabled=None,
-        queue_delay_milliseconds=None,
-        blob_auditing_policy_name=None):
+        queue_delay_milliseconds=None):
     _audit_policy_update(
         cmd=cmd,
         instance=instance,
@@ -902,8 +900,7 @@ def workspace_audit_policy_show(
         cmd,
         client,
         workspace_name,
-        resource_group_name,
-        blob_auditing_policy_name=None):
+        resource_group_name):
     '''
     Show workspace audit policy
     '''
@@ -913,7 +910,6 @@ def workspace_audit_policy_show(
         client=client,
         resource_group_name=resource_group_name,
         workspace_name=workspace_name,
-        blob_auditing_policy_name=blob_auditing_policy_name,
         category_name='SQLSecurityAuditEvents')
 
 
@@ -922,8 +918,7 @@ def sqlpool_audit_policy_show(
         client,
         workspace_name,
         resource_group_name,
-        sql_pool_name,
-        blob_auditing_policy_name=None):
+        sql_pool_name):
     '''
     Show sql pool audit policy
     '''
@@ -934,7 +929,6 @@ def sqlpool_audit_policy_show(
         resource_group_name=resource_group_name,
         workspace_name=workspace_name,
         sql_pool_name=sql_pool_name,
-        blob_auditing_policy_name=blob_auditing_policy_name,
         category_name='SQLSecurityAuditEvents')
 
 
@@ -944,8 +938,7 @@ def _audit_policy_show(
         resource_group_name,
         workspace_name,
         sql_pool_name=None,
-        category_name=None,
-        blob_auditing_policy_name=None):
+        category_name=None):
     '''
     Common code to get workspace or sqlpool audit policy including diagnostic settings
     '''
@@ -955,7 +948,7 @@ def _audit_policy_show(
         audit_policy = client.get(
             resource_group_name=resource_group_name,
             workspace_name=workspace_name,
-            blob_auditing_policy_name=blob_auditing_policy_name)
+            blob_auditing_policy_name='default')
     else:
         audit_policy = client.get(
             resource_group_name=resource_group_name,
