@@ -15,6 +15,10 @@ UPGRADE_MSG = 'Not able to upgrade automatically. Instructions can be found at h
 
 def rest_call(cmd, url, method=None, headers=None, uri_parameters=None,
               body=None, skip_authorization_header=False, resource=None, output_file=None):
+    from azure.cli.core.commands.transform import unregister_global_transforms
+    # No transform should be performed on `az rest`.
+    unregister_global_transforms(cmd.cli_ctx)
+
     from azure.cli.core.util import send_raw_request
     r = send_raw_request(cmd.cli_ctx, method, url, headers, uri_parameters, body,
                          skip_authorization_header, resource, output_file)
