@@ -25,6 +25,7 @@ class StorageProfile(Enum):
     ManagedCustomImage = 5
     ManagedSpecializedOSDisk = 6
     SharedGalleryImage = 7
+    CommunityGalleryImage = 8
 
 
 def build_deployment_resource(name, template, dependencies=None):
@@ -463,6 +464,19 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
                 "imageReference": {
                     'sharedGalleryImageId': image_reference
                 }
+            },
+            'CommunityGalleryImage': {
+                "osDisk": {
+                    "caching": os_caching,
+                    "managedDisk": {
+                        "storageAccountType": disk_info['os'].get('storageAccountType'),
+                    },
+                    "name": os_disk_name,
+                    "createOption": "fromImage"
+                },
+                "imageReference": {
+                    'communityGalleryImageId': image_reference
+                }
             }
         }
         if os_disk_encryption_set is not None:
@@ -475,6 +489,9 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
             storage_profiles['SharedGalleryImage']['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set,
             }
+            storage_profiles['CommunityGalleryImage']['osDisk']['managedDisk']['diskEncryptionSet'] = {
+                'id': os_disk_encryption_set,
+            }
 
         profile = storage_profiles[storage_profile.name]
         if os_disk_size_gb:
@@ -532,12 +549,13 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
             }
         }
 
-    vm_properties['additionalCapabilities'] = {}
-    if ultra_ssd_enabled is not None:
-        vm_properties['additionalCapabilities']['ultraSSDEnabled'] = ultra_ssd_enabled
+    if any((ultra_ssd_enabled, enable_hibernation)):
+        vm_properties['additionalCapabilities'] = {}
+        if ultra_ssd_enabled is not None:
+            vm_properties['additionalCapabilities']['ultraSSDEnabled'] = ultra_ssd_enabled
 
-    if enable_hibernation is not None:
-        vm_properties['additionalCapabilities']['hibernationEnabled'] = enable_hibernation
+        if enable_hibernation is not None:
+            vm_properties['additionalCapabilities']['hibernationEnabled'] = enable_hibernation
 
     if proximity_placement_group:
         vm_properties['proximityPlacementGroup'] = {'id': proximity_placement_group}
@@ -957,6 +975,20 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
             storage_properties['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set
             }
+    if storage_profile == StorageProfile.CommunityGalleryImage:
+        storage_properties['osDisk'] = {
+            'caching': os_caching,
+            'managedDisk': {'storageAccountType': disk_info['os'].get('storageAccountType')},
+            "name": os_disk_name,
+            "createOption": "fromImage"
+        }
+        storage_properties['imageReference'] = {
+            'communityGalleryImageId': image
+        }
+        if os_disk_encryption_set is not None:
+            storage_properties['osDisk']['managedDisk']['diskEncryptionSet'] = {
+                'id': os_disk_encryption_set
+            }
 
     if disk_info:
         data_disks = [v for k, v in disk_info.items() if k != 'os']
