@@ -17,7 +17,7 @@ except ImportError:
     logger.warn("Wheel is not available, disabling bdist_wheel hook")
     cmdclass = {}
 
-VERSION = "2.35.0"
+VERSION = "2.36.0"
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
 try:
@@ -59,17 +59,16 @@ DEPENDENCIES = [
     'azure-data-tables==12.2.0',
     'azure-datalake-store~=0.0.49',
     'azure-graphrbac~=0.60.0',
-    'azure-identity',
     'azure-keyvault-administration==4.0.0b3',
-    'azure-keyvault-keys==4.5.0b6',
+    'azure-keyvault-keys==4.5.1',
     'azure-keyvault~=1.1.0',
     'azure-loganalytics~=0.1.0',
     'azure-mgmt-advisor==9.0.0',
     'azure-mgmt-apimanagement~=3.0.0',
-    'azure-mgmt-appconfiguration~=2.1.0b2',
+    'azure-mgmt-appconfiguration==2.1.0b2',
     'azure-mgmt-applicationinsights~=1.0.0',
     'azure-mgmt-authorization~=0.61.0',
-    'azure-mgmt-batchai~=7.0.0b1',
+    'azure-mgmt-batchai==7.0.0b1',
     'azure-mgmt-batch~=16.1.0',
     'azure-mgmt-billing==6.0.0',
     'azure-mgmt-botservice~=0.3.0',
@@ -79,8 +78,8 @@ DEPENDENCIES = [
     'azure-mgmt-consumption~=2.0',
     'azure-mgmt-containerinstance~=9.1.0',
     'azure-mgmt-containerregistry==8.2.0',
-    'azure-mgmt-containerservice~=18.0.0',
-    'azure-mgmt-cosmosdb~=7.0.0b2',
+    'azure-mgmt-containerservice~=19.0.0',
+    'azure-mgmt-cosmosdb==7.0.0b2',
     'azure-mgmt-databoxedge~=1.0.0',
     'azure-mgmt-datalake-analytics~=0.2.1',
     'azure-mgmt-datalake-store~=0.5.0',
@@ -90,7 +89,7 @@ DEPENDENCIES = [
     'azure-mgmt-dns~=8.0.0',
     'azure-mgmt-eventgrid==9.0.0',
     'azure-mgmt-eventhub~=9.1.0',
-    'azure-mgmt-extendedlocation~=1.0.0b2',
+    'azure-mgmt-extendedlocation==1.0.0b2',
     'azure-mgmt-hdinsight~=9.0.0',
     'azure-mgmt-imagebuilder~=1.0.0',
     'azure-mgmt-iotcentral~=9.0.0',
@@ -98,12 +97,12 @@ DEPENDENCIES = [
     'azure-mgmt-iothubprovisioningservices==1.1.0',
     'azure-mgmt-keyvault==9.3.0',
     'azure-mgmt-kusto~=0.3.0',
-    'azure-mgmt-loganalytics~=13.0.0b2',
+    'azure-mgmt-loganalytics==13.0.0b4',
     'azure-mgmt-managedservices~=1.0',
     'azure-mgmt-managementgroups~=1.0.0',
     'azure-mgmt-maps~=2.0.0',
     'azure-mgmt-marketplaceordering==1.1.0',
-    'azure-mgmt-media~=8.0',
+    'azure-mgmt-media~=9.0',
     'azure-mgmt-monitor~=3.0.0',
     'azure-mgmt-msi~=6.0.0',
     'azure-mgmt-netapp~=7.0.0',
@@ -119,16 +118,16 @@ DEPENDENCIES = [
     'azure-mgmt-reservations==0.6.0',  # TODO: Use requirements.txt instead of '==' #9781
     'azure-mgmt-resource==20.0.0',
     'azure-mgmt-search~=8.0',
-    'azure-mgmt-security~=2.0.0b1',
+    'azure-mgmt-security==2.0.0b1',
     'azure-mgmt-servicebus~=7.1.0',
     'azure-mgmt-servicefabricmanagedclusters~=1.0.0',
     'azure-mgmt-servicelinker==1.0.0b2',
     'azure-mgmt-servicefabric~=1.0.0',
-    'azure-mgmt-signalr~=1.0.0b2',
-    'azure-mgmt-sqlvirtualmachine~=1.0.0b2',
+    'azure-mgmt-signalr==1.0.0b2',
+    'azure-mgmt-sqlvirtualmachine==1.0.0b2',
     'azure-mgmt-sql==4.0.0b1',
-    'azure-mgmt-storage~=19.1.0',
-    'azure-mgmt-synapse~=2.1.0b2',
+    'azure-mgmt-storage~=20.0.0',
+    'azure-mgmt-synapse==2.1.0b2',
     'azure-mgmt-trafficmanager~=1.0.0',
     'azure-mgmt-web~=6.1.0',
     'azure-multiapi-storage~=0.8.0',
